@@ -153,6 +153,7 @@ def ShowMap ():
 
 ###################################################
 def OpenMapWindow ():
+	import GameCheck
 	global MapWindow, OptionsWindow, PortraitWindow
 	global OldPortraitWindow, OldOptionsWindow
 
@@ -189,7 +190,7 @@ def OpenMapWindow ():
 	OldOptionsWindow = GUICommonWindows.OptionsWindow
 	OptionsWindow = GemRB.LoadWindow (0)
 	GUICommonWindows.MarkMenuButton (OptionsWindow)
-	GUICommonWindows.SetupMenuWindowControls (OptionsWindow, 0, OpenMapWindow)
+	GUICommonWindows.SetupMenuWindowControls (OptionsWindow, GameCheck.IsIWD2(), OpenMapWindow)
 	OptionsWindow.SetFrame ()
 
 	# World Map
@@ -226,6 +227,11 @@ def OpenMapWindow ():
 	else:
 		Map.SetStatus (IE_GUI_CONTROL_FOCUSED)
 
+	# create a button so we can map it do ESC for quit exiting
+	Button = Window.CreateButton (99, 0, 0, 1, 1)
+	Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, OpenMapWindow)
+	Button.SetFlags (IE_GUI_BUTTON_CANCEL, OP_OR)
+
 	GUICommonWindows.SetSelectionChangeHandler(None)
 	return
 
@@ -342,7 +348,7 @@ def MoveToNewArea ():
 
 	tmp = WorldMapControl.GetDestinationArea (1)
 	hours = tmp["Distance"]
-	CloseWorldMapWindow ()
+	OpenWorldMapWindow ()
 
 	if tmp["Destination"].lower() == GemRB.GetGameString(STR_AREANAME).lower():
 		return
@@ -394,8 +400,6 @@ def CloseWorldMapWindow ():
 	global WorldMapWindow, WorldMapControl
 	global OldPortraitWindow, OldOptionsWindow
 
-	assert GUICommon.CloseOtherWindow (CloseWorldMapWindow)
-
 	if WorldMapWindow:
 		WorldMapWindow.Unload ()
 	WorldMapWindow = None
@@ -420,6 +424,7 @@ def WorldMapWindowCommon (Travel):
 	global OldPortraitWindow, OldOptionsWindow
 
 	if GUICommon.CloseOtherWindow (CloseWorldMapWindow):
+		CloseWorldMapWindow ()
 		return
 
 	GemRB.HideGUI ()
