@@ -46,9 +46,10 @@ def OnLoad():
 	DoneButton = NameWindow.GetControl(0)
 	DoneButton.SetText(11973)
 	DoneButton.SetFlags(IE_GUI_BUTTON_DEFAULT,OP_OR)
-	DoneButton.SetState(IE_GUI_BUTTON_DISABLED)
 
 	NameField = NameWindow.GetControl(2)
+	NameField.SetText (GemRB.GetToken ("CHARNAME"))
+	EditChange ()
 
 	DoneButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, NextPress)
 	BackButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, CharGenCommon.BackPress)
@@ -63,6 +64,7 @@ def NextPress():
 	#seems like a good idea to store it here for the time being
 	MyChar = GemRB.GetVar ("Slot")
 	GemRB.SetPlayerName (MyChar, Name, 0)
+	GemRB.SetToken ("CHARNAME", Name)
 	CharGenCommon.next()
 	return
 
