@@ -33,8 +33,7 @@ def OnLoad():
 	TextAreaControl.SetText(10963)
 
 	TextAreaControl = ImportWindow.GetControl(2)
-	TextAreaControl.SetFlags (IE_GUI_TEXTAREA_SELECTABLE)
-	TextAreaControl.GetCharacters()
+	TextAreaControl.ListResources(CHR_EXPORTS)
  
 	DoneButton = ImportWindow.GetControl(0)
 	DoneButton.SetText(2610)
@@ -47,7 +46,7 @@ def OnLoad():
 
 	DoneButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, DonePress)
 	CancelButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, CancelPress)
-	TextAreaControl.SetEvent(IE_GUI_TEXTAREA_ON_CHANGE, SelectPress)
+	TextAreaControl.SetEvent(IE_GUI_TEXTAREA_ON_SELECT, SelectPress)
 	ImportWindow.SetVisible(WINDOW_VISIBLE)
 	return
 
@@ -60,6 +59,7 @@ def DonePress():
 	FileName = TextAreaControl.QueryText()
 	Slot = GemRB.GetVar("Slot")
 	GemRB.CreatePlayer(FileName, Slot| 0x8000, 1, 11) # 11 = force bg2
+	GemRB.SetToken ("CHARNAME", GemRB.GetPlayerName (Slot))
 	if ImportWindow:
 		ImportWindow.Unload()
 	# the medium portrait isn't available, so we copy the original hack
