@@ -20,14 +20,16 @@
  
 #include "Ambient.h"
 
+#include <algorithm>
+
 namespace GemRB {
 
 Ambient::Ambient()
 {
 	name[0] = 0;
-	radius = height = 0;
-	gain = interval = 0;
-	perset = appearance = flags = 0;
+	radius = 0;
+	gain = gainVariance = interval = intervalVariance = 0;
+	pitchVariance = appearance = flags = 0;
 }
 
 Ambient::~Ambient()
@@ -38,6 +40,35 @@ Ambient::~Ambient()
 	}
 }
 
+ieWord Ambient::getTotalGain() const
+{
+	ieWord g = gain;
+	if (gainVariance != 0) {
+		ieWord var = std::min(gainVariance, (ieWord) (gain/2));
+		g += -var + rand() % (2 * var);
+	}
+	return g;
+}
+
+ieDword Ambient::getTotalInterval() const
+{
+	ieDword i = interval;
+	if (intervalVariance != 0) {
+		ieWord var = std::min(intervalVariance, (ieDword) (interval/2));
+		i += -var + rand() % (2 * var);
+	}
+	return i;
+}
+
+ieDword Ambient::getTotalPitch() const
+{
+	ieDword p = 100;
+	if (pitchVariance != 0) {
+		p += -pitchVariance + rand() % (2 * pitchVariance);
+	}
+	return p;
+}
+
 void Ambient::setActive() { flags |= IE_AMBI_ENABLED; }
 void Ambient::setInactive() { flags &= ~IE_AMBI_ENABLED; }
 
