@@ -28,6 +28,8 @@
 #include "AnimStructures.h"
 #include "FactoryObject.h"
 
+namespace GemRB {
+
 class GEM_EXPORT AnimationFactory : public FactoryObject {
 private:
 	std::vector< Sprite2D*> frames;
@@ -56,4 +58,6 @@ public:
 	void DecDataRefCount();
 };
 
+}
+
 #endif
