@@ -20,12 +20,21 @@
 
 #include "Audio.h"
 
+namespace GemRB {
+
 const TypeID Audio::ID = { "Audio" };
 
 Audio::Audio(void)
 {
+	ambim = NULL;
 }
 
 Audio::~Audio(void)
 {
 }
+
+SoundHandle::~SoundHandle()
+{
+}
+
+}
