@@ -20,8 +20,11 @@
 
 #include "Cache.h"
 
+#include <cassert>
 #include <ctype.h>
 
+namespace GemRB {
+
 // private inlines
 inline unsigned int Cache::MyHashKey(const char* key) const
 {
@@ -309,3 +312,5 @@ void Cache::Cleanup()
 		pAssoc=nextAssoc;
 	}
 }
+
+}
