@@ -22,6 +22,8 @@
 
 #include "globals.h"
 
+namespace GemRB {
+
 Compressor::Compressor(void)
 {
 }
@@ -30,8 +32,4 @@ Compressor::~Compressor(void)
 {
 }
 
-// Initialization Function. Returns FALSE if there was an error during initialization, else returns TRUE.
-int Compressor::Init(void)
-{
-	return GEM_OK;
 }
