@@ -24,18 +24,18 @@
 #include "Plugin.h"
 #include "System/DataStream.h"
 
-#include <cstdio>
+namespace GemRB {
 
 class GEM_EXPORT Compressor : public Plugin {
 public:
 	Compressor(void);
 	virtual ~Compressor(void);
-	/** Initialization Function. Returns FALSE if there was an error during initialization, else returns TRUE. */
-	virtual int Init(void);
 	/** decompresses a datastream (memory or file) to a FILE * stream */
-	virtual int Decompress(FILE* dest, DataStream* source, unsigned int size_guess = 0) const = 0;
+	virtual int Decompress(DataStream* dest, DataStream* source, unsigned int size_guess = 0) const = 0;
 	/** compresses a datastream (memory or file) to another DataStream */
 	virtual int Compress(DataStream *dest, DataStream* source) const = 0;
 };
 
+}
+
 #endif
