@@ -32,6 +32,11 @@
 
 #include <cmath>
 #include <ctype.h>
+
+#if defined(__sgi)
+#include <iostream>
+#endif
+
 #ifdef WIN32
 #include "win32def.h"
 #ifdef _DEBUG
@@ -39,11 +44,13 @@
 #include <crtdbg.h>
 #endif
 
+BOOL WINAPI DllEntryPoint(HINSTANCE, DWORD, LPVOID);
 BOOL WINAPI DllEntryPoint(HINSTANCE /*hinstDLL*/, DWORD /*fdwReason*/,
 	LPVOID /*lpvReserved*/)
 {
 	return true;
 }
+
 #endif
 
 namespace GemRB {
@@ -76,7 +83,7 @@ unsigned int Distance(Point p, Point q)
 {
 	long x = ( p.x - q.x );
 	long y = ( p.y - q.y );
-	return (unsigned int) sqrt( ( double ) ( x* x + y* y ) );
+	return (unsigned int) std::sqrt( ( double ) ( x* x + y* y ) );
 }
 
 /** Calculates distance squared from a point to a scriptable */
@@ -92,14 +99,14 @@ unsigned int Distance(Point p, Scriptable *b)
 {
 	long x = ( p.x - b->Pos.x );
 	long y = ( p.y - b->Pos.y );
-	return (unsigned int) sqrt( ( double ) ( x* x + y* y ) );
+	return (unsigned int) std::sqrt( ( double ) ( x* x + y* y ) );
 }
 
 unsigned int PersonalDistance(Point p, Scriptable *b)
 {
 	long x = ( p.x - b->Pos.x );
 	long y = ( p.y - b->Pos.y );
-	int ret = (int) sqrt( ( double ) ( x* x + y* y ) );
+	int ret = (int) std::sqrt( ( double ) ( x* x + y* y ) );
 	if (b->Type==ST_ACTOR) {
 		ret-=((Actor *)b)->size*10;
 	}
@@ -132,7 +139,7 @@ unsigned int Distance(Scriptable *a, Scriptable *b)
 {
 	long x = ( a->Pos.x - b->Pos.x );
 	long y = ( a->Pos.y - b->Pos.y );
-	return (unsigned int) sqrt( ( double ) ( x* x + y* y ) );
+	return (unsigned int) std::sqrt( ( double ) ( x* x + y* y ) );
 }
 
 /** Calculates distance squared between 2 scriptables */
@@ -148,7 +155,7 @@ unsigned int PersonalDistance(Scriptable *a, Scriptable *b)
 {
 	long x = ( a->Pos.x - b->Pos.x );
 	long y = ( a->Pos.y - b->Pos.y );
-	int ret = (int) sqrt( ( double ) ( x* x + y* y ) );
+	int ret = (int) std::sqrt( ( double ) ( x* x + y* y ) );
 	if (a->Type==ST_ACTOR) {
 		ret-=((Actor *)a)->size*10;
 	}
@@ -218,8 +225,7 @@ int EARelation(Scriptable* Owner, Actor* target)
 // time from 0030 to 0129, bit 1 from 0130 to 0229 etc.
 bool Schedule(ieDword schedule, ieDword time)
 {
-	ieDword hour = 1 << (((time/AI_UPDATE_TIME)+(300/2))%7200/300);
-	return (schedule & hour) != 0;
+	return (schedule & SCHEDULE_MASK(time)) != 0;
 }
 
 // safely copies a ResRef (ie. nulls out the unused buffer size)
