@@ -102,8 +102,10 @@ GameControl::GameControl(const Region& frame)
 	numScrollCursor = 0;
 	DebugFlags = 0;
 	AIUpdateCounter = 1;
-	AlwaysRun = false; //make this a game flag if you wish
+
 	ieDword tmp=0;
+	core->GetDictionary()->Lookup("Always Run", tmp);
+	AlwaysRun = !!tmp;
 
 	ClearMouseState();
 	ResetTargetMode();
@@ -174,13 +176,13 @@ Point GameControl::GetFormationPoint(Map *map, unsigned int pos, Point src, Poin
 			angle = -M_PI_2;
 		}
 	} else {
-		angle = atan(xdiff/ydiff);
+		angle = std::atan(xdiff/ydiff);
 		if (ydiff < 0) angle += M_PI;
 	}
 
 	// calculate new coordinates by rotating formation around (0,0)
-	double newx = -formations[formation][pos].x * cos(angle) + formations[formation][pos].y * sin(angle);
-	double newy = formations[formation][pos].x * sin(angle) + formations[formation][pos].y * cos(angle);
+	double newx = -formations[formation][pos].x * std::cos(angle) + formations[formation][pos].y * std::sin(angle);
+	double newy = formations[formation][pos].x * std::sin(angle) + formations[formation][pos].y * std::cos(angle);
 	p.x += (int)newx;
 	p.y += (int)newy;
 
@@ -833,22 +835,15 @@ bool GameControl::OnKeyRelease(unsigned char Key, unsigned short Mod)
 					lastActor = area->GetActor( p, GA_DEFAULT);
 				}
 				if (lastActor && !(lastActor->GetStat(IE_MC_FLAGS)&MC_EXPORTABLE)) {
-					Actor *target;
-					int i = game->GetPartySize(true);
-					if(i<2) break;
-					i=RAND(0, i-1);
-					do
-					{
-						target = game->GetPC(i, true);
-						if(target==lastActor) continue;
-						if(target->GetStat(IE_MC_FLAGS)&MC_EXPORTABLE) continue;
-
-						char Tmp[40];
-						snprintf(Tmp,sizeof(Tmp),"Interact(\"%s\")",target->GetScriptName() );
-						lastActor->AddAction(GenerateAction(Tmp));
+					int size = game->GetPartySize(true);
+					if (size < 2 || game->NpcInParty < 2) break;
+					for (int i = core->Roll(1, size, 0); i < 2*size; i++) {
+						Actor *target = game->GetPC(i%size, true);
+						if (target == lastActor) continue;
+						if (target->GetStat(IE_MC_FLAGS) & MC_EXPORTABLE) continue; //not NPC
+						lastActor->HandleInteractV1(target);
 						break;
 					}
-					while(i--);
 				}
 				break;
 			case 'j': //teleports the selected actors
@@ -959,9 +954,8 @@ bool GameControl::OnKeyRelease(unsigned char Key, unsigned short Mod)
 					lastActor->GetNextStance();
 				}
 				break;
-			case 't'://advances time
-				// 7200 (one day) /24 (hours) == 300
-				game->AdvanceTime(300*AI_UPDATE_TIME);
+			case 't': // advances time by 1 hour
+				game->AdvanceTime(core->Time.hour_size);
 				//refresh gui here once we got it
 				break;
 			// u
@@ -1439,9 +1433,9 @@ end_function:
 /** Global Mouse Move Event */
 #if TARGET_OS_IPHONE
 // iOS will never have a mouse.
-void GameControl::OnGlobalMouseMove(unsigned short /*x*/, unsigned short /*y*/) {}
+void GameControl::OnGlobalMouseMove(short /*x*/, short /*y*/) {}
 #else
-void GameControl::OnGlobalMouseMove(unsigned short x, unsigned short y)
+void GameControl::OnGlobalMouseMove(short x, short y)
 {
 	if (ScreenFlags & SF_DISABLEMOUSE) {
 		return;
@@ -1489,15 +1483,17 @@ void GameControl::MoveViewportTo(int x, int y, bool center) {
 		x -= vp.w/2;
 		y -= vp.h/2;
 	}
+	if (x + vp.w >= mapsize.x) {
+		x = mapsize.x - vp.w - 1;
+	}
 	if (x < 0) {
 		x = 0;
-	} else if (x + vp.w >= mapsize.x) {
-		x = mapsize.x - vp.w - 1;
+	}
+	if (y + vp.h >= mapsize.y) {
+		y = mapsize.y - vp.h - 1;
 	}
 	if (y < 0) {
 		y = 0;
-	} else if (y + vp.h >= mapsize.y) {
-		y = mapsize.y - vp.h - 1;
 	}
 
 	// override any existing viewport moves which may be in progress
@@ -1880,6 +1876,7 @@ void GameControl::OnMouseDown(unsigned short x, unsigned short y, unsigned short
 		break;
 	case GEM_MB_ACTION|GEM_MB_DOUBLECLICK:
 		DoubleClick = true;
+		// intentional fallthrough
 	case GEM_MB_ACTION:
 		// PST uses alt + left click for formation rotation
 		// is there any harm in this being true in all games?
@@ -1953,74 +1950,73 @@ void GameControl::OnMouseUp(unsigned short x, unsigned short y, unsigned short B
 				actor = NULL;
 			}
 		}
-		switch (Button) {
-			case GEM_MB_ACTION:
-				if (!actor) {
-					Actor *pc = core->GetFirstSelectedPC(false);
-					if (!pc) {
-						//this could be a non-PC
-						pc = game->selected[0];
-					}
-					//add a check if you don't want some random monster handle doors and such
-					if (overDoor) {
-						HandleDoor(overDoor, pc);
-						break;
-					}
-					if (overContainer) {
-						HandleContainer(overContainer, pc);
-						break;
-					}
-					if (overInfoPoint) {
-						if (overInfoPoint->Type==ST_TRAVEL) {
-							ieDword exitID = overInfoPoint->GetGlobalID();
-							if (core->HasFeature(GF_TEAM_MOVEMENT)) {
-								// pst forces everyone to travel (eg. ar0201 outside_portal)
-								int i = game->GetPartySize(false);
-								while(i--) {
-									game->GetPC(i, false)->UseExit(exitID);
-								}
-							} else {
-								int i = game->selected.size();
-								while(i--) {
-									game->selected[i]->UseExit(exitID);
-								}
+
+		if (Button & GEM_MB_ACTION) {
+			if (!actor) {
+				Actor *pc = core->GetFirstSelectedPC(false);
+				if (!pc) {
+					//this could be a non-PC
+					pc = game->selected[0];
+				}
+				//add a check if you don't want some random monster handle doors and such
+				if (overDoor) {
+					HandleDoor(overDoor, pc);
+					goto formation_handling;
+				}
+				if (overContainer) {
+					HandleContainer(overContainer, pc);
+					goto formation_handling;
+				}
+				if (overInfoPoint) {
+					if (overInfoPoint->Type==ST_TRAVEL) {
+						ieDword exitID = overInfoPoint->GetGlobalID();
+						if (core->HasFeature(GF_TEAM_MOVEMENT)) {
+							// pst forces everyone to travel (eg. ar0201 outside_portal)
+							int i = game->GetPartySize(false);
+							while(i--) {
+								game->GetPC(i, false)->UseExit(exitID);
+							}
+						} else {
+							int i = game->selected.size();
+							while(i--) {
+								game->selected[i]->UseExit(exitID);
 							}
 						}
-						if (HandleActiveRegion(overInfoPoint, pc, p)) {
-							core->SetEventFlag(EF_RESETTARGET);
-							break;
-						}
 					}
-					//just a single actor, no formation
-					if (game->selected.size()==1
-						&& target_mode == TARGET_MODE_CAST
-						&& spellCount
-						&& (target_types&GA_POINT)) {
-						//the player is using an item or spell on the ground
-						TryToCast(pc, p);
-						break;
+					if (HandleActiveRegion(overInfoPoint, pc, p)) {
+						core->SetEventFlag(EF_RESETTARGET);
+						goto formation_handling;
 					}
 				}
-				doMove = (!actor && target_mode == TARGET_MODE_NONE);
-				break;
-			case GEM_MB_MENU:
-				// we used to check mod in this case,
-				// but it doesnt make sense to initiate an action based on a mod on mouse down
-				// then cancel that action because the mod disapeared before mouse up
-				if (!core->HasFeature(GF_HAS_FLOAT_MENU)) {
-					SetTargetMode(TARGET_MODE_NONE);
+				//just a single actor, no formation
+				if (game->selected.size()==1
+					&& target_mode == TARGET_MODE_CAST
+					&& spellCount
+					&& (target_types&GA_POINT)) {
+					//the player is using an item or spell on the ground
+					TryToCast(pc, p);
+					goto formation_handling;
 				}
-				if (!actor) {
-					// reset the action bar
-					core->GetGUIScriptEngine()->RunFunction("GUICommonWindows", "EmptyControls");
-					core->SetEventFlag(EF_ACTION);
-				}
-				break;
-			default:
-				return; // we dont handle any other buttons beyond this point
+			}
+			doMove = (!actor && target_mode == TARGET_MODE_NONE);
+		} else if (Button & GEM_MB_MENU) {
+			// we used to check mod in this case,
+			// but it doesnt make sense to initiate an action based on a mod on mouse down
+			// then cancel that action because the mod disapeared before mouse up
+			if (!core->HasFeature(GF_HAS_FLOAT_MENU)) {
+				SetTargetMode(TARGET_MODE_NONE);
+			}
+			if (!actor) {
+				// reset the action bar
+				core->GetGUIScriptEngine()->RunFunction("GUICommonWindows", "EmptyControls");
+				core->SetEventFlag(EF_ACTION);
+			}
+		} else {
+			return; // we dont handle any other buttons beyond this point
 		}
 	}
 
+formation_handling:
 	if (doMove && game->selected.size() > 0) {
 		// construct a sorted party
 		// TODO: this is still ugly, help?
@@ -2686,6 +2682,7 @@ void GameControl::SetDisplayText(ieStrRef text, unsigned int time)
 void GameControl::ToggleAlwaysRun()
 {
 	AlwaysRun = !AlwaysRun;
+	core->GetDictionary()->SetAt("Always Run", AlwaysRun);
 }
 
 }
