@@ -50,6 +50,13 @@ TextArea::TextArea(const Region& frame, Font* text, Font* caps,
 	// quick font optimization (prevents creating unnecessary cap spans)
 	finit = (caps != ftext) ? caps : ftext;
 
+	// in case a bad or missing font was specified, use an obvious fallback
+	if (!finit) {
+		Log(ERROR, "TextArea", "Tried to use missing font, resorting to a fallback!");
+		finit = core->GetTextFont();
+		ftext = finit;
+	}
+
 	if (finit->Baseline < ftext->LineHeight) {
 		// FIXME: initcolor is only used for *some* initial fonts
 		// this is a hack to workaround the INITIALS font getting its palette set
@@ -158,6 +165,9 @@ void TextArea::SetAnimPicture(Sprite2D* pic)
 		// FIXME: in the original dialog is always indented (even without portrait), I doubt we care, but mentioning it here.
 		frame.w -= offset;
 	}
+	if (frame.w < 0) {
+		frame.w = 0;
+	}
 	// FIXME: content containers should support the "flexible" idiom so we can resize children by resizing parent
 	textContainer->SetFrame(Region(Point(), frame));
 	contentWrapper.SetFrame(Region(Point(), frame));
