@@ -40,6 +40,8 @@
 #include "GUI/GameControl.h"
 #include "System/DataStream.h"
 #include "System/StringBuffer.h"
+#include "Video.h"
+#include "MapReverb.h"
 
 #include <algorithm>
 #include <iterator>
@@ -86,6 +88,7 @@ Game::Game(void) : Scriptable( ST_GLOBAL )
 	protagonist = PM_YES; //set it to 2 for iwd/iwd2 and 0 for pst
 	partysize = 6;
 	Ticks = 0;
+	GameTime = RealTime = 0;
 	version = 0;
 	Expansion = 0;
 	LoadMos[0] = 0;
@@ -113,6 +116,10 @@ Game::Game(void) : Scriptable( ST_GLOBAL )
 	weather = new Particles(200);
 	weather->SetRegion(0, 0, core->Width, core->Height);
 	LastScriptUpdate = 0;
+	WhichFormation = 0;
+	NpcInParty = 0;
+	CurrentLink = 0;
+	PartyAttack = false;
 
 	//loading master areas
 	AutoTable table;
@@ -431,7 +438,10 @@ int Game::LeaveParty (Actor* actor)
 	NPCs.push_back( actor );
 
 	if (core->HasFeature( GF_HAS_DPLAYER )) {
-		actor->SetScript( "", SCR_DEFAULT );
+		// we must reset various existing scripts
+		actor->SetScript("", SCR_CLASS, false);
+		actor->SetScript("", SCR_RACE, false);
+		actor->SetScript("WTASIGHT", SCR_GENERAL, false);
 		if (actor->GetBase(IE_MC_FLAGS) & MC_EXPORTABLE) {
 			actor->SetDialog("MULTIJ");
 		}
@@ -515,6 +525,16 @@ int Game::JoinParty(Actor* actor, int join)
 		actor->ReinitQuickSlots();
 		//set the joining date
 		actor->PCStats->JoinDate = GameTime;
+		//if the protagonist has the same portrait replace it
+		Actor *prot = GetPC(0, false);
+		if (prot && (!strcmp(actor->SmallPortrait, prot->SmallPortrait) || !strcmp(actor->LargePortrait, prot->LargePortrait))) {
+			AutoTable ptab("portrait");
+			if (ptab) {
+				CopyResRef(actor->SmallPortrait, ptab->QueryField(actor->SmallPortrait, "REPLACEMENT"));
+				CopyResRef(actor->LargePortrait, ptab->QueryField(actor->LargePortrait, "REPLACEMENT"));
+			}
+		}
+
 		if (size) {
 			ieDword id = actor->GetGlobalID();
 			for (size_t i=0;i<size; i++) {
@@ -531,7 +551,6 @@ int Game::JoinParty(Actor* actor, int join)
 		NPCs.erase( m );
 	}
 
-
 	PCs.push_back( actor );
 	if (!actor->InParty) {
 		actor->InParty = (ieByte) (size+1);
@@ -581,6 +600,8 @@ bool Game::SelectPCSingle(int index)
 		return false;
 
 	SelectedSingle = index;
+	core->SetEventFlag(EF_SELECTION);
+
 	return true;
 }
 
@@ -939,6 +960,10 @@ int Game::LoadMap(const char* ResRef, bool loadscreen)
 	}
 	newMap->InitActors();
 
+	if (newMap->reverb) {
+		core->GetAudioDrv()->UpdateMapAmbient(*newMap->reverb);
+	}
+
 	return ret;
 failedload:
 	if (hide) {
@@ -963,7 +988,7 @@ bool Game::CheckForReplacementActor(int i)
 		for (it = npclevels.begin(); it != npclevels.end(); it++) {
 			if (!stricmp((*it)[0], act->GetScriptName()) && (level > 2)) {
 				// the tables have entries only up to level 24
-				ieDword safeLevel = npclevels[0].size() - 1;
+				ieDword safeLevel = npclevels[0].size();
 				if (level < safeLevel) {
 					safeLevel = level;
 				}
@@ -1319,17 +1344,31 @@ void Game::PartyMemberDied(Actor *actor)
 	//this could be null, in some extreme cases...
 	Map *area = actor->GetCurrentArea();
 
-	for (unsigned int i=0; i<PCs.size(); i++) {
-		if (PCs[i]==actor) {
+	unsigned int size = PCs.size();
+	Actor *react = NULL;
+	for (unsigned int i = core->Roll(1, size, 0), n = 0; n < size; i++, n++) {
+		Actor *pc = PCs[i%size];
+		if (pc == actor) {
 			continue;
 		}
-		if (PCs[i]->GetStat(IE_STATE_ID)&STATE_DEAD) {
+		if (pc->GetStat(IE_STATE_ID)&STATE_DEAD) {
 			continue;
 		}
-		if (PCs[i]->GetCurrentArea()!=area) {
+		if (pc->GetStat(IE_MC_FLAGS) & MC_EXPORTABLE) {
 			continue;
 		}
-		PCs[i]->ReactToDeath(actor->GetScriptName());
+		if (pc->GetCurrentArea()!=area) {
+			continue;
+		}
+		if (pc->HasSpecialDeathReaction(actor->GetScriptName())) {
+			react = pc;
+			break;
+		} else if (react == NULL) {
+			react = pc;
+		}
+	}
+	if (react != NULL) {
+		react->ReactToDeath(actor->GetScriptName());
 	}
 }
 
@@ -1384,17 +1423,40 @@ void Game::AddGold(ieDword add)
 	}
 }
 
+EffectRef fx_set_regenerating_state_ref = { "State:Regenerating", -1 };
+
 //later this could be more complicated
 void Game::AdvanceTime(ieDword add, bool fatigue)
 {
-	ieDword h = GameTime/(300*AI_UPDATE_TIME);
+	ieDword h = GameTime/core->Time.hour_size;
 	GameTime+=add;
-	if (h!=GameTime/(300*AI_UPDATE_TIME)) {
+	if (h!=GameTime/core->Time.hour_size) {
 		//asking for a new weather when the hour changes
 		WeatherBits&=~WB_HASWEATHER;
 		//update clock display
 		core->GetGUIScriptEngine()->RunFunction("GUICommonWindows", "UpdateClock");
 	}
+
+	// emulate speeding through effects than need more than just an expiry check (eg. regeneration)
+	// but only if we skip for at least an hour
+	if (add >= core->Time.hour_size) {
+		for (unsigned int i=0; i<PCs.size(); i++) {
+			Actor *pc = PCs[i];
+			int conHealRate = pc->GetConHealAmount();;
+			// 1. regeneration as an effect
+			// No matter the mode, if it is persistent, the actor will get fully healed in an hour.
+			// However the effect does its own timekeeping, so we can't easily check the duration,
+			// so we treat all regeneration as permanent - the most common kind (eg. from rings)
+			if (pc->fxqueue.HasEffect(fx_set_regenerating_state_ref)) {
+				pc->Heal(0);
+			} else if (conHealRate) {
+				// 2. regeneration from high constitution / TNO
+				// some of the speeds are very slow, so calculate the accurate amount
+				pc->Heal(add / conHealRate);
+			}
+		}
+	}
+
 	Ticks+=add*interval;
 	if (!fatigue) {
 		// update everyone in party, so they think no time has passed
@@ -1703,7 +1765,8 @@ bool Game::RestParty(int checks, int dream, int hp)
 		}
 		//area encounters
 		// also advances gametime (so partial rest is possible)
-		hoursLeft = area->CheckRestInterruptsAndPassTime( leader->Pos, hours, (GameTime/AI_UPDATE_TIME)%7200/3600);
+		// TODO: should take time of day into account (GameScript::TimeOfDay)
+		hoursLeft = area->CheckRestInterruptsAndPassTime( leader->Pos, hours, core->Time.GetHour(GameTime)/12);
 		if (hoursLeft) {
 			// partial rest only, so adjust the parameters for the loop below
 			if (hp) {
@@ -1720,7 +1783,7 @@ bool Game::RestParty(int checks, int dream, int hp)
 			}
 		}
 	} else {
-		AdvanceTime(hours*300*AI_UPDATE_TIME);
+		AdvanceTime(hours * core->Time.hour_size);
 	}
 
 	int i = GetPartySize(true); // party size, only alive
@@ -1940,23 +2003,36 @@ bool Game::TimeStoppedFor(const Actor* target)
 //recalculate the party's infravision state
 void Game::Infravision()
 {
-	ieDword tmp = 0;
 	hasInfra = false;
-	core->GetDictionary()->Lookup("infravision", tmp);
-	if (!tmp) return;
 	Map *map = GetCurrentArea();
 	if (!map) return;
+
+	ieDword tmp = 0;
+	core->GetDictionary()->Lookup("infravision", tmp);
+
+	bool someoneWithInfravision = false;
+	bool allSelectedWithInfravision = true;
+	bool someoneSelected = false;
+
 	for(size_t i=0;i<PCs.size();i++) {
 		Actor *actor = PCs[i];
 		if (!IsAlive(actor)) continue;
 		if (actor->GetCurrentArea()!=map) continue;
-		//Group infravision overrides this???
-		if (!actor->Selected) continue;
-		if (actor->GetStat(IE_STATE_ID) & STATE_INFRA) {
-			hasInfra = true;
-			return;
+
+		bool hasInfravision = actor->GetStat(IE_STATE_ID) & STATE_INFRA;
+		someoneWithInfravision |= hasInfravision;
+
+		someoneSelected |= actor->Selected;
+		if (actor->Selected) {
+			allSelectedWithInfravision &= hasInfravision;
+		}
+
+		if ((someoneWithInfravision && tmp) || (!tmp && !allSelectedWithInfravision)) {
+			break;
 		}
 	}
+
+	hasInfra = (tmp && someoneWithInfravision) || (allSelectedWithInfravision && someoneSelected);
 }
 
 //returns the colour which should be applied onto the whole game area viewport
@@ -1977,7 +2053,7 @@ const Color *Game::GetGlobalTint() const
 	}
 	if ((map->AreaType&(AT_OUTDOOR|AT_DAYNIGHT|AT_EXTENDED_NIGHT)) == (AT_OUTDOOR|AT_DAYNIGHT) ) {
 		//get daytime colour
-		ieDword daynight = ((GameTime/AI_UPDATE_TIME)%7200/300);
+		ieDword daynight = core->Time.GetHour(GameTime);
 		if (daynight<2 || daynight>22) {
 			return &NightTint;
 		}
@@ -1998,9 +2074,24 @@ const Color *Game::GetGlobalTint() const
 	return NULL;
 }
 
+// applies the global tint, if any
+void Game::ApplyGlobalTint(Color &tint, ieDword &flags) const
+{
+	const Color *globalTint = GetGlobalTint();
+	if (globalTint) {
+		if (flags & BLIT_TINTED) {
+			Color::MultiplyTint(tint, globalTint);
+		} else {
+			flags |= BLIT_TINTED;
+			tint = *globalTint;
+			tint.a = 255;
+		}
+	}
+}
+
 bool Game::IsDay()
 {
-	ieDword daynight = ((GameTime/AI_UPDATE_TIME)%7200/300);
+	ieDword daynight = core->Time.GetHour(GameTime);
 	if(daynight<4 || daynight>20) {
 		return false;
 	}
@@ -2012,13 +2103,16 @@ void Game::ChangeSong(bool always, bool force)
 	int Song;
 	static int BattleSong = 0;
 
+	if (!area) return;
+
 	if (CombatCounter) {
 		//battlesong
 		Song = SONG_BATTLE;
 		BattleSong++;
 	} else {
 		//will select SONG_DAY or SONG_NIGHT
-		Song = (GameTime/AI_UPDATE_TIME)%7200/3600;
+		// TODO: should this take time of day into account?
+		Song = core->Time.GetHour(GameTime)/12;
 		BattleSong = 0;
 	}
 	//area may override the song played (stick in battlemusic)
@@ -2143,7 +2237,7 @@ void Game::dump() const
 	if (Scripts[0]) {
 		buffer.appendFormatted("Global script: %s\n", Scripts[0]->GetName());
 	}
-	int hours = GameTime/AI_UPDATE_TIME/300;
+	int hours = GameTime/core->Time.hour_size;
 	buffer.appendFormatted("Game time: %d (%d days, %d hours)\n", GameTime, hours/24, hours%24);
 	buffer.appendFormatted("CombatCounter: %d\n", (int) CombatCounter);
 
