@@ -511,6 +511,7 @@ void DisplayStringCore(Scriptable* const Sender, int Strref, int flags)
 	if (Sound[0] && !(flags&DS_SILENT) ) {
 		ieDword speech = GEM_SND_RELATIVE; //disable position
 		if (flags&DS_SPEECH) speech|=GEM_SND_SPEECH;
+		if (flags&DS_QUEUE) speech|=GEM_SND_QUEUE;
 		unsigned int len = 0;
 		core->GetAudioDrv()->Play( Sound,0,0,speech,&len );
 		ieDword counter = ( AI_UPDATE_TIME * len ) / 1000;
@@ -737,10 +738,10 @@ void CreateCreatureCore(Scriptable* Sender, Action* parameters, int flags)
 			pnt.y = vp.y+vp.h/2;
 			break;
 			}
-			//falling through
+			//fall through
 		case CC_OBJECT://use object + offset
 			if (tmp) Sender=tmp;
-			//falling through
+			//fall through
 		case CC_OFFSET://use sender + offset
 			pnt.x = parameters->pointParameter.x+Sender->Pos.x;
 			pnt.y = parameters->pointParameter.y+Sender->Pos.y;
@@ -749,8 +750,13 @@ void CreateCreatureCore(Scriptable* Sender, Action* parameters, int flags)
 			pnt.x = parameters->pointParameter.x;
 			pnt.y = parameters->pointParameter.y;
 			if (pnt.isempty()) {
-				pnt.x = Sender->Pos.x;
-				pnt.y = Sender->Pos.y;
+				if (Sender->Type == ST_PROXIMITY || Sender->Type == ST_TRIGGER) {
+					pnt.x = ((InfoPoint *)Sender)->TrapLaunch.x;
+					pnt.y = ((InfoPoint *)Sender)->TrapLaunch.y;
+				} else {
+					pnt.x = Sender->Pos.x;
+					pnt.y = Sender->Pos.y;
+				}
 			}
 			break;
 	}
@@ -814,7 +820,13 @@ void CreateVisualEffectCore(Scriptable *Sender, const Point &position, const cha
 	if (vvc) {
 		vvc->XPos +=position.x;
 		vvc->YPos +=position.y;
-		Sender->GetCurrentArea( )->AddVVCell( new VEFObject(vvc) );
+		Map *area = Sender->GetCurrentArea();
+		if (area) {
+			area->AddVVCell(new VEFObject(vvc));
+		} else {
+			Log(WARNING, "GSUtils", "Skipping visual effect positioning due to missing area!");
+			delete vvc;
+		}
 	}
 }
 
@@ -915,6 +927,7 @@ void GetPositionFromScriptable(Scriptable* scr, Point &position, bool dest)
 				position=((InfoPoint *) scr)->UsePoint;
 				break;
 			}
+		// intentional fallthrough
 		case ST_DOOR: case ST_CONTAINER:
 			position=((Highlightable *) scr)->TrapLaunch;
 	}
@@ -982,13 +995,14 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 			Sender->ReleaseCurrentAction();
 			return;
 		}
-		//DialogueRange is set in IWD
-		ieDword range = MAX_OPERATING_DISTANCE + speaker->GetBase(IE_DIALOGRANGE);
 		//making sure speaker is the protagonist, player, actor
-		if ( target->InParty == 1) swap = true;
-		else if ( speaker->InParty !=1 && target->InParty) swap = true;
+		Actor *protagonist = core->GetGame()->GetPC(0, false);
+		if (target == protagonist) swap = true;
+		else if (speaker != protagonist && target->InParty) swap = true;
 		//CHECKDIST works only for mobile scriptables
 		if (Flags&BD_CHECKDIST) {
+			//DialogueRange is set in IWD
+			ieDword range = MAX_OPERATING_DISTANCE + speaker->GetBase(IE_DIALOGRANGE);
 			if ( scr->GetCurrentArea()!=target->GetCurrentArea() ||
 				PersonalDistance(scr, target)>range) {
 				MoveNearerTo(Sender, target, MAX_OPERATING_DISTANCE);
