@@ -33,7 +33,7 @@
 
 // absent from msvc6
 #ifdef _MSC_VER
-#ifndef __FUNCTION
+#ifndef __FUNCTION__
 #define __FUNCTION__ "no message"
 #endif
 #endif
@@ -58,6 +58,7 @@ class StringBuffer;
 #define DS_SILENT  32
 #define DS_SPEECH  64
 #define DS_AREA    128
+#define DS_QUEUE   256
 
 //verbal constant (bg2), we have a lookup table (vcremap) for other games
 #define VB_INITIALMEET 0
@@ -87,7 +88,10 @@ class StringBuffer;
 #define VB_TIMMUNE   67
 #define VB_INVENTORY 68
 #define VB_PP_SUCC   69
+#define VB_EXISTENCE 69
+#define VB_HIDE      70
 #define VB_SPELL_DISRUPTED 71
+#define VB_TRAP_SET  72
 #define VB_BIO       74
 
 //diffmode (iwd2)
@@ -621,6 +625,7 @@ public: //Script Functions
 	static int CombatCounterLT(Scriptable* Sender, Trigger* parameters);
 	static int Contains(Scriptable* Sender, Trigger* parameters);
 	static int CreatureHidden( Scriptable* Sender, Trigger* parameters);
+	static int CurrentAmmo(Scriptable* Sender, Trigger* parameters);
 	static int CurrentAreaIs(Scriptable* Sender, Trigger* parameters);
 	static int DamageTaken(Scriptable* Sender, Trigger* parameters);
 	static int DamageTakenGT(Scriptable* Sender, Trigger* parameters);
@@ -882,6 +887,7 @@ public: //Script Functions
 	static int StateCheck(Scriptable* Sender, Trigger* parameters);
 	static int StealFailed(Scriptable* Sender, Trigger* parameters);
 	static int StoreHasItem(Scriptable* Sender, Trigger* parameters);
+	static int StoryModeOn(Scriptable* Sender, Trigger* /*parameters*/);
 	static int StuffGlobalRandom(Scriptable* Sender, Trigger* parameters);
 	static int SubRace(Scriptable* Sender, Trigger* parameters);
 	static int SummoningLimit(Scriptable* Sender, Trigger* parameters);
@@ -943,6 +949,7 @@ public:
 	static void AddSpecialAbility(Scriptable* Sender, Action* parameters);
 	static void AddSuperKit(Scriptable* Sender, Action* parameters);
 	static void AddWayPoint(Scriptable* Sender, Action* parameters);
+	static void AddWorldmapAreaFlag(Scriptable* /*Sender*/, Action* parameters);
 	static void AddXP2DA(Scriptable *Sender, Action* parameters);
 	static void AddXPObject(Scriptable *Sender, Action* parameters);
 	static void AdvanceTime(Scriptable *Sender, Action* parameters);
@@ -1245,6 +1252,7 @@ public:
 	static void RemoveRangerHood(Scriptable* Sender, Action* parameters);
 	static void RemoveSpell(Scriptable* Sender, Action* parameters);
 	static void RemoveTraps(Scriptable* Sender, Action* parameters);
+	static void RemoveWorldmapAreaFlag(Scriptable* /*Sender*/, Action* parameters);
 	static void ReputationInc(Scriptable* Sender, Action* parameters);
 	static void ReputationSet(Scriptable* Sender, Action* parameters);
 	static void RestorePartyLocation(Scriptable *Sender, Action* parameters);
@@ -1301,6 +1309,7 @@ public:
 	static void SetHPPercent(Scriptable* Sender, Action* parameters);
 	static void SetInternal(Scriptable* Sender, Action* parameters);
 	static void SetInterrupt(Scriptable* Sender, Action* parameters);
+	static void SetItemFlags(Scriptable* Sender, Action* parameters);
 	static void SetLeavePartyDialogFile(Scriptable* Sender, Action* parameters);
 	static void SetMarkedSpell(Scriptable* Sender, Action* parameters);
 	static void SetMasterArea(Scriptable* Sender, Action* parameters);
