@@ -829,7 +829,7 @@ void IniSpawn::SpawnGroup(SpawnEntry &event)
 	}
 	unsigned int interval = event.interval;
 	if (interval) {
-		if (core->GetGame()->GameTime + interval <= last_spawndate) {
+		if (last_spawndate + interval >= core->GetGame()->GameTime) {
 			return;
 		}
 	}
