@@ -184,6 +184,8 @@ public:
 	{
 		Weight=-1; //invalid weight
 		MaxStackAmount=0;
+		Flags = 0;
+		Expired = 0;
 	}
 };
 
@@ -261,8 +263,6 @@ public:
 	/** count == ~0 means to destroy all */
 	/** returns the number of destroyed items */
 	unsigned int DestroyItem(const char *resref, ieDword flags, ieDword count);
-	/** flags: see ieCREItemFlagBits */
-	void SetItemFlags(CREItem* item, ieDword flags);
 	void SetSlotItem(CREItem* item, unsigned int slot);
 	int GetWeight() const {return Weight;}
 
@@ -291,6 +291,7 @@ public:
 	/** Returns the item's inventory flags */
 	ieDword GetItemFlag(unsigned int slot) const;
 	/** Changes the inventory flags */
+	/** flags: see ieCREItemFlagBits */
 	bool ChangeItemFlag(ieDword slot, ieDword value, int mode);
 	/** Equips the item, don't use it directly for weapons */
 	bool EquipItem(ieDword slot);
@@ -332,7 +333,7 @@ public:
 	/** returns the strref for the reason why the item cannot be equipped */
 	int WhyCantEquip(int slot, int twohanded) const;
 	/** returns a slot that has a stealable item */
-	unsigned int FindStealableItem();
+	int FindStealableItem();
 	/** checks if any equipped item provides critical hit aversion */
 	bool ProvidesCriticalAversion();
 	/** tries to merge the passed item with the one in the passed slot */
