@@ -30,6 +30,7 @@
 
 #include "Item.h"
 #include "Plugin.h"
+#include "TableMgr.h"
 #include "System/DataStream.h"
 
 namespace GemRB {
@@ -40,6 +41,10 @@ namespace GemRB {
  */
 
 class GEM_EXPORT ItemMgr : public Plugin {
+protected:
+	AutoTable tooltipTable; // tooltips (duh)
+	AutoTable exclusionTable; // a table of items that are mutually exclusive
+	AutoTable dialogTable; // dialogs attached to items (conversables such as Lilarcor)
 public:
 	ItemMgr(void);
 	virtual ~ItemMgr(void);
