@@ -33,6 +33,8 @@
 
 #include "Resource.h"
 
+namespace GemRB {
+
 /**
  * @class MoviePlayer
  * Abstract loader and player for videos
@@ -47,4 +49,6 @@ public:
 	virtual void CallBackAtFrames(ieDword cnt, ieDword *frames, ieDword *strrefs) = 0;
 };
 
+}
+
 #endif
