@@ -87,23 +87,25 @@ static inline voidvoid my_dlsym(void *handle, const char *symbol)
 #ifdef WIN32
 #define FREE_PLUGIN( handle )  FreeLibrary( handle )
 #define GET_PLUGIN_SYMBOL( handle, name )  GetProcAddress( handle, name )
-#define PRINT_DLERROR
 #else
 #define FREE_PLUGIN( handle )  dlclose( handle )
 #define GET_PLUGIN_SYMBOL( handle, name )  my_dlsym( handle, name )
-#define PRINT_DLERROR Log(MESSAGE, "PluginLoader", "Error: %s", dlerror() )
 #endif
 
 /** Return names of all *.so or *.dll files in the given directory */
 #ifdef WIN32
+
 static bool FindFiles( char* path, std::list<char*> &files )
 {
 	//The windows _findfirst/_findnext functions allow the use of wildcards so we'll use them :)
 	struct _finddata_t c_file;
 	long hFile;
 	strcat( path, "*.dll" );
-	if (( hFile = ( long ) _findfirst( path, &c_file ) ) == -1L) //If there is no file matching our search
+	if (( hFile = ( long ) _findfirst( path, &c_file ) ) == -1L) {
+		//If there is no file matching our search
+		Log(ERROR, "PluginLoader", "Error looking up dlls.");
 		return false;
+	}
 
 	do {
 		files.push_back( strdup( c_file.name ));
@@ -139,11 +141,13 @@ void LoadPlugins(char* pluginpath)
 	Log(MESSAGE, "PluginMgr", "Loading Plugins from %s", pluginpath);
 
 	char path[_MAX_PATH];
-	strcpy( path, pluginpath );
+	strlcpy(path, pluginpath, _MAX_PATH);
 
 	std::list< char * > files;
-	if (! FindFiles( path, files ))
+	if (! FindFiles( path, files )) {
+		Log(ERROR, "PluginLoader", "Cannot find any plugins!");
 		return;
+	}
 
 	//Iterate through all the available modules to load
 	int file_count = files.size (); // keeps track of first-pass files
@@ -184,7 +188,6 @@ void LoadPlugins(char* pluginpath)
 #endif
 		if (hMod == NULL) {
 			Log(ERROR, "PluginLoader", "Cannot Load \"%s\", skipping...", path);
-			PRINT_DLERROR;
 			continue;
 		}
 
