@@ -27,7 +27,7 @@ struct GEM_EXPORT PolymorphCache {
 	ieResRef Resource;
 	ieDword *stats;
 
-	PolymorphCache() : stats(NULL) { }
+	PolymorphCache() : stats(NULL) { Resource[0] = 0; }
 	~PolymorphCache() {
 		delete[] stats;
 	}
