@@ -78,6 +78,12 @@ Projectile::Projectile()
 	drawSpark = 0;
 	ZPos = 0;
 	extension_delay = 0;
+	RGB = ColorSpeed = Shake = TFlags = Seq1 = Seq2 = Speed = SFlags = ExtFlags = 0;
+	IDSType = IDSValue = IDSType2 = IDSValue2 = StrRef = 0;
+	LightX = LightY = LightZ = Aim = type = SparkColor = 0;
+	SmokeSpeed = SmokeAnimID = Caster = Target = Level = 0;
+	extension_explosioncount = extension_targetcount = 0;
+	memset(&tint, 0, sizeof(tint));
 	if (!server)
 		server = core->GetProjectileServer();
 }
@@ -1161,7 +1167,7 @@ void Projectile::SecondaryTarget()
 			//int width = (*poi)->GetAnims()->GetCircleSize();
 
 			if (ydiff) {
-				deg = (int) (atan(xdiff/ydiff)*180/M_PI);
+				deg = (int) (std::atan(xdiff/ydiff)*180/M_PI);
 				if(ydiff>0) deg+=180;
 			} else {
 				if (xdiff<0) deg=90;
@@ -1504,8 +1510,8 @@ void Projectile::DrawExplosion(const Region &screen)
 			}
 			max=core->Roll(1,max,add);
 			double degree=max*M_PI/180;
-			newdest.x = (int) -(rad * sin(degree) );
-			newdest.y = (int) (rad * cos(degree) );
+			newdest.x = (int) -(rad * std::sin(degree) );
+			newdest.y = (int) (rad * std::cos(degree) );
 			
 			//these fields and flags are always inherited by all children
 			pro->Speed = Speed;
@@ -1610,8 +1616,11 @@ void Projectile::SetupWall()
 void Projectile::DrawLine(const Region &screen, int face, ieDword flag)
 {
 	Video *video = core->GetVideoDriver();
+	Game *game = core->GetGame();
 	PathNode *iter = path;
 	Sprite2D *frame = travel[face]->NextFrame();
+	Color tint2 = tint;
+	if (game) game->ApplyGlobalTint(tint2, flag);
 	while(iter) {
 		Point pos(iter->x, iter->y);
 
@@ -1621,7 +1630,7 @@ void Projectile::DrawLine(const Region &screen, int face, ieDword flag)
 		pos.x+=screen.x;
 		pos.y+=screen.y;
 
-		video->BlitGameSprite( frame, pos.x, pos.y, flag, tint, NULL, palette, &screen);
+		video->BlitGameSprite( frame, pos.x, pos.y, flag, tint2, NULL, palette, &screen);
 		iter = iter->Next;
 	}
 }
@@ -1629,6 +1638,7 @@ void Projectile::DrawLine(const Region &screen, int face, ieDword flag)
 void Projectile::DrawTravel(const Region &screen)
 {
 	Video *video = core->GetVideoDriver();
+	Game *game = core->GetGame();
 	ieDword flag;
 
 	if(ExtFlags&PEF_HALFTRANS) {
@@ -1672,7 +1682,7 @@ void Projectile::DrawTravel(const Region &screen)
 		// (this could use travelled and a larger constant multiplier,
 		// to make the arc size fixed rather than relative to the total
 		// distance to travel)
-		double length_of_normal = travelled_distance * sin(arc_angle) * 0.3 * ((bend / 2) + 1);
+		double length_of_normal = travelled_distance * std::sin(arc_angle) * 0.3 * ((bend / 2) + 1);
 		if (bend % 2) length_of_normal = -length_of_normal;
 
 		// adjust the to-be-rendered point by that distance
@@ -1684,8 +1694,15 @@ void Projectile::DrawTravel(const Region &screen)
 		pos = newpos;
 	}
 
+	// set up the tint for the rest of the blits, but don't overwrite the saved one
+	Color tint2 = tint;
+	ieDword flags = flag;
+	if (TFlags&PTF_TINT) {
+		if (game) game->ApplyGlobalTint(tint2, flags);
+	}
+
 	if (light) {
-		video->BlitGameSprite( light, pos.x, pos.y, 0, tint, NULL, NULL, &screen);
+		video->BlitGameSprite(light, pos.x, pos.y, flags^flag, tint2, NULL, NULL, &screen);
 	}
 
 	if (ExtFlags&PEF_POP) {
@@ -1706,8 +1723,8 @@ void Projectile::DrawTravel(const Region &screen)
 					frame = shadow[0]->NextFrame();
 				}
 			}
-			
-			video->BlitGameSprite( frame, pos.x, pos.y, flag, tint, NULL, palette, &screen);
+
+			video->BlitGameSprite(frame, pos.x, pos.y, flags, tint2, NULL, palette, &screen);
 			return;
 	}
 	
@@ -1718,7 +1735,7 @@ void Projectile::DrawTravel(const Region &screen)
 	
 	if (shadow[face]) {
 		Sprite2D *frame = shadow[face]->NextFrame();
-		video->BlitGameSprite( frame, pos.x, pos.y, flag, tint, NULL, palette, &screen);
+		video->BlitGameSprite(frame, pos.x, pos.y, flags, tint2, NULL, palette, &screen);
 	}
 
 	pos.y-=GetZPos();
@@ -1728,14 +1745,14 @@ void Projectile::DrawTravel(const Region &screen)
 		for(int i=0;i<Aim;i++) {
 			if (travel[i]) {
 				Sprite2D *frame = travel[i]->NextFrame();
-				video->BlitGameSprite( frame, pos.x, pos.y, flag, tint, NULL, palette, &screen);
+				video->BlitGameSprite( frame, pos.x, pos.y, flags, tint2, NULL, palette, &screen);
 				pos.y-=frame->YPos;
 			}
 		}
 	} else {
 		if (travel[face]) {
 			Sprite2D *frame = travel[face]->NextFrame();
-			video->BlitGameSprite( frame, pos.x, pos.y, flag, tint, NULL, palette, &screen);
+			video->BlitGameSprite( frame, pos.x, pos.y, flags, tint2, NULL, palette, &screen);
 		}
 	}
 
