@@ -25,6 +25,8 @@
 #include "Projectile.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 class GEM_EXPORT ProjectileMgr : public Plugin {
 public:
 	ProjectileMgr(void);
@@ -33,4 +35,6 @@ public:
 	virtual Projectile* GetProjectile( Projectile *) = 0;
 };
 
+}
+
 #endif
