@@ -20,7 +20,9 @@
 
 #include "Resource.h"
 
-#include "DataStream.h"
+#include "System/DataStream.h"
+
+namespace GemRB {
 
 Resource::Resource(void)
 {
@@ -33,3 +35,5 @@ Resource::~Resource(void)
 		delete( str );
 	}
 }
+
+}
