@@ -64,7 +64,7 @@ static void ParseGameDate(DataStream *ds, char *Date)
 		return;
 	}
 
-	int hours = ((int)GameTime)/300;
+	int hours = ((int)GameTime)/core->Time.hour_sec;
 	int days = hours/24;
 	hours -= days*24;
 	char *a=NULL,*b=NULL,*c=NULL;
@@ -370,8 +370,8 @@ Holder<SaveGame> SaveGameIterator::BuildSaveGame(const char *slotname)
 
 void SaveGameIterator::PruneQuickSave(const char *folder)
 {
-	char from[_MAX_PATH];
-	char to[_MAX_PATH];
+	char from[_MAX_PATH+20];
+	char to[_MAX_PATH+20];
 
 	//storing the quicksave ages in an array
 	std::vector<int> myslots;
@@ -513,8 +513,9 @@ static int CanSave()
 	int i = game->GetPartySize(true);
 	while(i--) {
 		Actor *actor = game->GetPC(i, true);
-		//TODO: can't save while (party) actors are in helpless states
-		if (actor->GetStat(IE_STATE_ID) & STATE_NOSAVE) {
+		// can't save while (party) actors are in helpless or dead states
+		// STATE_NOSAVE tracks actors not to be stored in GAM, not game saveability
+		if (actor->GetStat(IE_STATE_ID) & (STATE_NOSAVE|STATE_MINDLESS)) {
 			//some actor is in nosave state
 			displaymsg->DisplayConstantString(STR_CANTSAVENOCTRL, DMC_BG2XPGREEN);
 			return 5;
@@ -533,7 +534,7 @@ static int CanSave()
 	}
 
 	Point pc1 =  game->GetPC(0, true)->Pos;
-	Actor **nearActors = map->GetAllActorsInRadius(pc1, GA_NO_DEAD|GA_NO_UNSCHEDULED, 15*4);
+	Actor **nearActors = map->GetAllActorsInRadius(pc1, GA_NO_DEAD|GA_NO_UNSCHEDULED, 15*10);
 	i = 0;
 	while (nearActors[i]) {
 		Actor *actor = nearActors[i];
