@@ -323,7 +323,6 @@ public:
 	int LastDamageType;
 	int LastDamage;
 	Point FollowOffset;//follow lastfollowed at this offset
-	Point HomeLocation;//spawnpoint, return here after rest
 	bool Spawned;      //has been created by a spawn point
 
 	ieDword TargetDoor;
@@ -339,6 +338,7 @@ public:
 	ieDword panicMode;           //runaway, berserk or randomwalk
 	ieDword nextComment;         //do something random (area comment, interaction)
 	ieDword nextBored;           //do something when bored
+	int FatigueComplaintDelay;   // stagger tired messages
 	ieDword lastInit;
 	int speed;
 	//how many attacks left in this round, must be public for cleave opcode
@@ -350,6 +350,7 @@ public:
 private:
 	//this stuff doesn't get saved
 	CharAnimations* anims;
+	CharAnimations *shadowAnimations;
 	SpriteCover* extraCovers[EXTRA_ACTORCOVERS];
 	ieByte SavingThrow[5];
 	// true when command has been played after select
@@ -367,7 +368,7 @@ private:
 	char AttackStance;
 	/*The projectile bringing the current attack*/
 	Projectile* attackProjectile ;
-	int TicksLastRested;
+	ieDword TicksLastRested;
 	/** paint the actor itself. Called internally by Draw() */
 	void DrawActorSprite(const Region &screen, int cx, int cy, const Region& bbox,
 				SpriteCover*& sc, Animation** anims,
@@ -401,7 +402,8 @@ private:
 	void UpdateFatigue();
 	int GetSneakAttackDamage(Actor *target, WeaponInfo &wi, int &multiplier, bool weaponImmunity);
 	int GetBackstabDamage(Actor *target, WeaponInfo &wi, int multiplier, int damage) const;
-	void ApplyModal(ieResRef modalSpell);
+	/** for IE_EXISTANCEDELAY */
+	void PlayExistenceSounds();
 public:
 	Actor(void);
 	~Actor(void);
@@ -530,13 +532,16 @@ public:
 	void Interact(int type);
 	/* returns a remapped verbal constant strref */
 	ieStrRef GetVerbalConstant(int index) const;
+	/* returns a random remapped verbal constant strref */
+	ieStrRef GetVerbalConstant(int start, int count) const;
 	/* displaying a random verbal constant */
-	void VerbalConstant(int start, int count, bool force=false) const;
+	void VerbalConstant(int start, int count, bool queue=false) const;
 	/* display string or verbal constant depending on what is available */
 	void DisplayStringOrVerbalConstant(int str, int vcstat, int vccount) const;
 	/* inlined dialogue response */
 	void Response(int type) const;
 	/* called when someone died in the party */
+	bool HasSpecialDeathReaction(const char *deadname) const;
 	void ReactToDeath(const char *deadname);
 	/* sends trigger_died to everyone in visual range */
 	void SendDiedTrigger();
@@ -576,9 +581,9 @@ public:
 	/* sets some of the internal flags */
 	void SetRunFlags(ieDword flags);
 	/* applies the kit abilities, returns false if kit is not applicable */
-	bool ApplyKit(bool remove, ieDword baseclass=0);
+	bool ApplyKit(bool remove, ieDword baseclass=0, int diff=0);
 	/* applies the class abilities*/
-	void ApplyClab(const char *clab, ieDword max, bool remove);
+	void ApplyClab(const char *clab, ieDword max, int remove, int diff);
 	/* calls InitQuickSlot in PCStatStruct */
 	void SetupQuickSlot(unsigned int which, int slot, int headerindex);
 	/* returns true if the actor is PC/joinable*/
@@ -616,6 +621,8 @@ public:
 	void SetModal(ieDword newstate, bool force=1);
 	/* Sets the modal spell after checks */
 	void SetModalSpell(ieDword state, const char *spell);
+	/* casts the modal spell if any */
+	void ApplyModal(ieResRef modalSpell);
 	/* returns current attack style */
 	int GetAttackStyle() const;
 	/* adds the combatants to the attackers list */
@@ -653,7 +660,7 @@ public:
 	/* applies modal spell etc, if needed */
 	void UpdateActorState(ieDword gameTime);
 	/* returns the hp adjustment based on constitution */
-	int GetHpAdjustment(int multiplier) const;
+	int GetHpAdjustment(int multiplier, bool modified=true) const;
 	/* does all the housekeeping after loading the actor from file */
 	void InitStatsOnLoad();
 	/* sets a colour gradient stat, handles location */
@@ -675,6 +682,8 @@ public:
 	void GetAreaComment(int areaflag) const;
 	/* handle oneliner interaction, -1: unsuccessful (may comment area), 0: dialog banter, 1: oneliner */
 	int HandleInteract(Actor *target);
+	/* start bg1-style banter dialog */
+	void HandleInteractV1(Actor *target);
 	/* generate party banter, return true if successful */
 	bool GetPartyComment();
 	/* sets the quick slots */
@@ -730,6 +739,7 @@ public:
 	int RestoreSpellLevel(ieDword maxlevel, ieDword typemask);
 	/* rememorizes spells, cures fatigue, etc */
 	void Rest(int hours);
+	int GetConHealAmount() const;
 	/* returns the portrait icons list */
 	const unsigned char *GetStateString() const;
 	/* adds a state icon to the list */
@@ -794,6 +804,7 @@ public:
 	bool IsDualClassed() const;
 	/* Returns an exact copy of this actor */
 	Actor *CopySelf(bool mislead) const;
+	static ieDword GetClassID (const ieDword isclass);
 	/* Returns the actor's level of the given class */
 	ieDword GetFighterLevel() const { return GetClassLevel(ISFIGHTER); }
 	ieDword GetMageLevel() const { return GetClassLevel(ISMAGE); }
@@ -863,6 +874,7 @@ public:
 	/* returns the armor check penalty */
 	int GetArmorSkillPenalty(int profcheck=1) const;
 	int GetArmorSkillPenalty(int profcheck, int &armor, int &shield) const;
+	int GetArmorWeightClass(ieWord armorType) const;
 	int GetTotalArmorFailure() const;
 	int GetArmorFailure(int &armor, int &shield) const;
 	bool IsDead() const;
@@ -881,11 +893,13 @@ public:
 	void ReleaseCurrentAction();
 	bool ConcentrationCheck() const;
 	void ApplyEffectCopy(Effect *oldfx, EffectRef &newref, Scriptable *Owner, ieDword param1, ieDword param2);
+	ieDword GetLastRested() { return TicksLastRested; }
 	void IncreaseLastRested(int inc) { TicksLastRested += inc; }
 	bool WasClass(ieDword oldClassID) const;
 	unsigned int GetSubRace() const;
 	std::list<int> ListLevels() const;
 	void ChangeSorcererType (ieDword classIdx);
+	unsigned int GetAdjustedTime(unsigned int time) const;
 };
 }
 
