@@ -31,6 +31,8 @@
 #include "Spell.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 /**
  * @class SpellMgr
  * Abstract loader for Spell objects
@@ -40,8 +42,10 @@ class GEM_EXPORT SpellMgr : public Plugin {
 public:
 	SpellMgr(void);
 	virtual ~SpellMgr(void);
-	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
+	virtual bool Open(DataStream* stream) = 0;
 	virtual Spell* GetSpell(Spell *spl, bool silent=false) = 0;
 };
 
+}
+
 #endif
