@@ -38,7 +38,7 @@ namespace GemRB {
 
 //bah!
 class CREItem;
-class Trigger;
+class Condition;
 
 typedef enum StoreType { STT_STORE=0, STT_TAVERN=1, STT_INN=2, STT_TEMPLE=3,
 STT_BG2CONT=4, STT_IWD2CONT=5 } StoreType;
@@ -76,7 +76,7 @@ struct GEM_EXPORT STOItem {
 	ieDword AmountInStock;
 	ieDwordSigned InfiniteSupply;
 	// V1.1
-	Trigger *trigger;
+	Condition *triggers;
 	//ieDword TriggerRef; use infinitesupply
 	char unknown2[56];
 	
@@ -170,7 +170,6 @@ public: //queries
 	void IdentifyItem(CREItem *item) const;
 	/** Adds a new item to the store (selling) */
 	void AddItem(CREItem* item);
-	void RemoveItem(unsigned int idx);
 	void RemoveItem( STOItem *itm);
 	/** Returns index of item */
 	unsigned int FindItem(const ieResRef item, bool usetrigger) const;
