@@ -33,6 +33,8 @@
 #include "exports.h"
 #include "globals.h"
 
+namespace GemRB {
+
 /**
  * @class FileStream
  * Reads and writes data from/to files on a filesystem
@@ -40,6 +42,9 @@
 
 class GEM_EXPORT FileStream : public DataStream {
 private:
+#ifdef _DEBUG
+	static int FileStreamPtrCount;
+#endif
 	struct File;
 	File* str;
 	bool opened, created;
@@ -56,6 +61,8 @@ public:
 	int Read(void* dest, unsigned int length);
 	int Write(const void* src, unsigned int length);
 	int Seek(int pos, int startpos);
+
+	void Close();
 public:
 	/** Opens the specifed file.
 	 *
@@ -64,7 +71,8 @@ public:
 	static FileStream* OpenFile(const char* filename);
 private:
 	void FindLength();
-	void Close();
 };
 
+}
+
 #endif  // ! FILESTREAM_H
