@@ -21,7 +21,11 @@
 #include "System/Logger.h"
 #include "System/StringBuffer.h"
 
-#include <cstdarg>
+#if defined(__sgi)
+#  include <stdarg.h>
+#else
+#  include <cstdarg>
+#endif
 #include <vector>
 
 namespace GemRB {
@@ -69,16 +73,18 @@ static void vLog(log_level level, const char* owner, const char* message, log_co
 		return;
 
 	// Copied from System/StringBuffer.cpp
-#if defined(_MSC_VER)
+#ifndef __va_copy
 	// Don't try to be smart.
 	// Assume this is long enough. If not, message will be truncated.
 	// MSVC6 has old vsnprintf that doesn't give length
 	const size_t len = 4095;
 #else
-	va_list ap_copy;
-	va_copy(ap_copy, ap);
-	const size_t len = vsnprintf(NULL, 0, message, ap_copy);
-	va_end(ap_copy);
+    va_list ap_copy;
+    // __va_copy should always be defined
+    // va_copy is only defined by C99 (C++11 and up)
+    __va_copy(ap_copy, ap);
+    const size_t len = vsnprintf(NULL, 0, message, ap_copy);
+    va_end(ap_copy);
 #endif
 
 #if defined(__GNUC__)
