@@ -27,6 +27,10 @@
 #include "globals.h"
 #include "win32def.h"
 
+#include <cassert>
+
+namespace GemRB {
+
 #ifndef ReleaseFun
 typedef void (*ReleaseFun)(void *);
 #endif
@@ -102,6 +106,9 @@ public:
 
 	iterator GetNextAssoc(iterator rNextPosition, const char*& rKey,
 		ieDword& rValue) const;
+
+	// Debugging
+	void DebugDump();
 	// Implementation
 protected:
 	Variables::MyAssoc** m_pHashTable;
@@ -124,4 +131,6 @@ public:
 	~Variables();
 };
 
+}
+
 #endif
