@@ -47,8 +47,8 @@ Video::Video(void)
 
 	// Initialize gamma correction tables
 	for (int i = 0; i < 256; i++) {
-		Gamma22toGamma10[i] = (unsigned char)(0.5 + (pow (i/255.0, 2.2/1.0) * 255.0));
-		Gamma10toGamma22[i] = (unsigned char)(0.5 + (pow (i/255.0, 1.0/2.2) * 255.0));
+		Gamma22toGamma10[i] = (unsigned char)(0.5 + (std::pow (i/255.0, 2.2/1.0) * 255.0));
+		Gamma10toGamma22[i] = (unsigned char)(0.5 + (std::pow (i/255.0, 1.0/2.2) * 255.0));
 	}
 
 	// boring inits just to be extra clean
@@ -209,11 +209,6 @@ void Video::SetMouseGrayed(bool grayed)
 	}
 }
 
-bool Video::TouchInputEnabled() const
-{
-	return MouseFlags & (MOUSE_GRAYED|MOUSE_DISABLED);
-}
-
 /** Get the fullscreen mode */
 bool Video::GetFullscreenMode() const
 {
