@@ -28,8 +28,11 @@
 #define WINDOWMGR_H
 
 #include "Plugin.h"
-#include "GUI/Window.h"
-#include "System/DataStream.h"
+
+namespace GemRB {
+
+class DataStream;
+class Window;
 
 /**
  * @class WindowMgr
@@ -42,11 +45,13 @@ public:
 	WindowMgr();
 	virtual ~WindowMgr();
 	/** This function loads all available windows from the 'stream' parameter. */
-	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
+	virtual bool Open(DataStream* stream) = 0;
 	/** Returns the i-th window in the Previously Loaded Stream */
 	virtual Window* GetWindow(unsigned int i) = 0;
 	/** Returns the number of available windows */
 	virtual unsigned int GetWindowsCount() = 0;
 };
 
+}
+
 #endif
