@@ -34,7 +34,7 @@
 
 #include "ie_types.h"
 
-#define VERSION_GEMRB "0.8.4"
+#define VERSION_GEMRB "0.8.5"
 
 #define GEMRB_STRING "GemRB v" VERSION_GEMRB
 
@@ -78,6 +78,9 @@ namespace GemRB {
 #define IE_STR_STRREFOFF  256
 #define IE_STR_REMOVE_NEWLINE  0x1000 // gemrb extension: remove extraneus ending newline
 
+// checked against the strref itself
+#define IE_STR_ALTREF 0x0100000 // use alternate tlk file: dialogf.tlk
+
 // bitflag operations
 // !!! Keep these synchronized with GUIDefines.py !!!
 #define OP_SET  0 //gemrb extension
@@ -161,10 +164,10 @@ namespace GemRB {
 #define  GF_HEAL_ON_100PLUS             71 //bg1, bg2, pst
 #define  GF_IN_PARTY_ALLOWS_DEAD	72 //all except bg2
 #define  GF_ZERO_TIMER_IS_VALID         73 // how, not bg2, other unknown
-#define  GF_SKIPUPDATE_HACK             74 // how, not bg2
+#define  GF_SHOP_RECHARGE               74 // all?
 #define  GF_MELEEHEADER_USESPROJECTILE  75 // minimally bg2
 #define  GF_FORCE_DIALOGPAUSE           76 // all except if using v1.04 DLG files (bg2, special)
-#define  GF_SHOP_RECHARGE               77 // all?
+#define  GF_RANDOM_BANTER_DIALOGS       77 // bg1
 
 //update this or bad things can happen
 #define GF_COUNT 78
@@ -198,6 +201,7 @@ GEM_EXPORT int EARelation(Scriptable *a, Actor *b);
 GEM_EXPORT bool Schedule(ieDword schedule, ieDword time);
 GEM_EXPORT void CopyResRef(ieResRef d, const ieResRef s);
 
+#define SCHEDULE_MASK(time)	(1 << core->Time.GetHour(time + core->Time.hour_size/2))
 
 #ifndef WIN32
 inline unsigned long GetTickCount()
