@@ -122,6 +122,7 @@ namespace GemRB {
 #define STATE_BLIND      0x00040000
 //this appears to be a mistake in the original state.ids
 //this flag is the 'deactivate' flag, Activate/Deactivate works on it
+// NOTE: we use IF_VISIBLE instead, so it could be removed if any conflict with disease arises
 #define STATE_DISEASED   0x00080000
 #define STATE_DEACTIVATED 0x00080000
 #define STATE_FEEBLE     0x00100000
@@ -143,14 +144,16 @@ namespace GemRB {
 #define STATE_CONFUSED   0x80000000
 
 #define STATE_STILL      (STATE_STUNNED | STATE_FROZEN | STATE_PETRIFIED) //0xc8: not animated
+#define _DEAD_STATES     (STATE_EXPLODING|STATE_FLAME|STATE_ACID|STATE_DEAD|STATE_PETRIFIED|STATE_FROZEN) //0x0fc0: just a shorthand
+#define STATE_MINDLESS  (STATE_CONFUSED|STATE_FEEBLE|STATE_CHARMED|STATE_HELPLESS|STATE_SLEEP|STATE_BERSERK|STATE_PANIC) // 0x80102027
 
 // can't walk or attack - helpless
 // FIXME: why is STATE_BERSERK on the list?
-#define STATE_CANTMOVE (STATE_SLEEP|STATE_BERSERK|STATE_PANIC|STATE_STUNNED|STATE_HELPLESS|STATE_FROZEN|STATE_PETRIFIED|STATE_EXPLODING|STATE_FLAME|STATE_ACID|STATE_DEAD|STATE_DEACTIVATED|STATE_FEEBLE) // 0x180fef
-#define STATE_CANTLISTEN 0x80080fef
-#define STATE_CANTSTEAL  0x00180fc0 //can't steal from
-#define STATE_CANTSEE    0x00080fc0 //can't explore (even itself)
-#define STATE_NOSAVE     0x00000fc0 //don't save these
+#define STATE_CANTMOVE ((STATE_MINDLESS|STATE_STUNNED|_DEAD_STATES|STATE_DEACTIVATED)^(STATE_CHARMED|STATE_CONFUSED)) // 0x180fef
+#define STATE_CANTSTEAL  (_DEAD_STATES|STATE_DEACTIVATED|STATE_FEEBLE) //can't steal from, 0x00180fc0
+#define STATE_CANTSEE    (_DEAD_STATES|STATE_DEACTIVATED) //can't explore (even itself), 0x00080fc0
+#define STATE_CANTLISTEN ((STATE_CANTSEE|STATE_STUNNED|STATE_MINDLESS)^(STATE_CHARMED|STATE_FEEBLE)) // 0x80080fef
+#define STATE_NOSAVE     _DEAD_STATES //don't save these, 0x00000fc0
 
 #define EXTSTATE_PRAYER      0x00000001
 #define EXTSTATE_PRAYER_BAD  0x00000002
