@@ -21,6 +21,8 @@
 
 #include "win32def.h" //for stricmp
 
+namespace GemRB {
+
 struct iless {
 	bool operator () (const char *lhs, const char* rhs) const
 	{
@@ -28,4 +30,6 @@ struct iless {
 	}
 };
 
+}
+
 #endif
