@@ -26,13 +26,14 @@
 #include "globals.h"
 
 #include <cstring>
+#include <vector>
+
+namespace GemRB {
 
 typedef std::vector< char*> RowEntry;
 
 class p2DAImporter : public TableMgr {
 private:
-	DataStream* str;
-	bool autoFree;
 	std::vector< char*> colNames;
 	std::vector< char*> rowNames;
 	std::vector< char*> ptrs;
@@ -41,7 +42,7 @@ private:
 public:
 	p2DAImporter(void);
 	~p2DAImporter(void);
-	bool Open(DataStream* stream, bool autoFree = true);
+	bool Open(DataStream* stream);
 	/** Returns the actual number of Rows in the Table */
 	inline ieDword GetRowCount() const
 	{
@@ -164,6 +165,20 @@ public:
 		}
 		return -1;
 	}
+
+	inline int FindTableValue(const char* col, long val, int start) const
+	{
+		ieDword coli = GetColumnIndex(col);
+		return FindTableValue(coli, val, start);
+	}
+
+	inline int FindTableValue(const char* col, const char* val, int start) const
+	{
+		ieDword coli = GetColumnIndex(col);
+		return FindTableValue(coli, val, start);
+	}
 };
 
+}
+
 #endif
