@@ -130,6 +130,19 @@ static int GetTrackString(const ieResRef areaName)
 
 AREImporter::AREImporter(void)
 {
+	EntrancesOffset = ContainersOffset = InfoPointsOffset = SpawnOffset = 0;
+	EntrancesCount = ContainersCount = InfoPointsCount = SpawnCount = 0;
+	ItemsOffset = VariablesOffset = AmbiOffset = TileOffset = TrapOffset = 0;
+	ItemsCount = VariablesCount = AmbiCount = TileCount = TrapCount = 0;
+	ActorCount = VerticesCount = NoteCount = 0;
+	ActorOffset = VerticesOffset = NoteOffset = EffectOffset = 0;
+	AreaDifficulty = AreaFlags = AreaType = 0;
+	SongHeader = RestHeader = bigheader = 0;
+	WRain = WSnow = WFog = WLightning = WUnknown = 0;
+	EmbeddedCreOffset = AnimOffset = AnimCount = DoorsOffset = DoorsCount = 0;
+	ExploredBitmapSize = ExploredBitmapOffset = 0;
+	LastSave = 0;
+
 	str = NULL;
 	if (Sounds[0][0] == UNINITIALIZED_BYTE) {
 		memset( Sounds, 0, sizeof( Sounds ) );
@@ -254,7 +267,7 @@ bool AREImporter::ChangeMap(Map *map, bool day_or_night)
 	if (day_or_night) {
 		memcpy( TmpResRef, map->WEDResRef, 9);
 	} else {
-		snprintf( TmpResRef, 9, "%sN", map->WEDResRef);
+		snprintf( TmpResRef, 9, "%.7sN", map->WEDResRef);
 	}
 	PluginHolder<TileMapMgr> tmm(IE_WED_CLASS_ID);
 	DataStream* wedfile = gamedata->GetResource( TmpResRef, IE_WED_CLASS_ID );
@@ -272,7 +285,7 @@ bool AREImporter::ChangeMap(Map *map, bool day_or_night)
 	}
 	tm = tmm->GetTileMap(tm);
 	if (!tm) {
-		print("[AREImporter]: No Tile Map Available.");
+		Log(ERROR, "AREImporter", "No tile map available.");
 		return false;
 	}
 
@@ -290,19 +303,31 @@ bool AREImporter::ChangeMap(Map *map, bool day_or_night)
 
 	//get the lightmap name
 	if (day_or_night) {
-		snprintf( TmpResRef, 9, "%sLM", map->WEDResRef);
+		snprintf( TmpResRef, 9, "%.6sLM", map->WEDResRef);
 	} else {
-		snprintf( TmpResRef, 9, "%sLN", map->WEDResRef);
+		snprintf( TmpResRef, 9, "%.6sLN", map->WEDResRef);
 	}
 
 	ResourceHolder<ImageMgr> lm(TmpResRef);
 	if (!lm) {
-		print("[AREImporter]: No lightmap available.");
+		Log(ERROR, "AREImporter", "No lightmap available.");
 		return false;
 	}
 
 	//alter the lightmap and the minimap (the tileset was already swapped)
 	map->ChangeTileMap(lm->GetImage(), sm?sm->GetSprite2D():NULL);
+
+	// update the tiles and tilecount (eg. door0304 in Edwin's Docks (ar0300) entrance
+	for (size_t i = 0; i < tm->GetDoorCount(); i++) {
+		Door* door = tm->GetDoor(i);
+		bool baseClosed, oldOpen = door->IsOpen();
+		int count;
+		unsigned short *indices = tmm->GetDoorIndices(door->ID, &count, baseClosed);
+		door->SetTiles(indices, count);
+		// reset open state to the one in the old wed
+		door->SetDoorOpen(oldOpen, true, 0);
+	}
+
 	return true;
 }
 
@@ -343,8 +368,9 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		day_or_night = true;
 
 	Map* map = new Map();
-	if(!map) {
-		error("AREImporter", "Can't allocate map (out of memory).\n");
+	if (!map) {
+		Log(ERROR, "AREImporter", "Can't allocate map (out of memory).");
+		return NULL;
 	}
 	if (core->SaveAsOriginal) {
 		map->version = bigheader;
@@ -373,7 +399,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	if (!core->IsAvailable( IE_WED_CLASS_ID )) {
-		print("[AREImporter]: No Tile Map Manager Available.");
+		Log(ERROR, "AREImporter", "No tile map manager available.");
 		delete map;
 		return NULL;
 	}
@@ -382,7 +408,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	if (day_or_night) {
 		memcpy( TmpResRef, WEDResRef, 9);
 	} else {
-		snprintf( TmpResRef, 9, "%sN", WEDResRef);
+		snprintf( TmpResRef, 9, "%.7sN", WEDResRef);
 	}
 
 	PluginHolder<TileMapMgr> tmm(IE_WED_CLASS_ID);
@@ -392,7 +418,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	//there was no tilemap set yet, so lets just send a NULL
 	TileMap* tm = tmm->GetTileMap(NULL);
 	if (!tm) {
-		print("[AREImporter]: No Tile Map Available.");
+		Log(ERROR, "AREImporter", "No tile map available.");
 		delete map;
 		return NULL;
 	}
@@ -418,30 +444,30 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	if (day_or_night) {
-		snprintf( TmpResRef, 9, "%sLM", WEDResRef);
+		snprintf( TmpResRef, 9, "%.6sLM", WEDResRef);
 	} else {
-		snprintf( TmpResRef, 9, "%sLN", WEDResRef);
+		snprintf( TmpResRef, 9, "%.6sLN", WEDResRef);
 	}
 
 	ResourceHolder<ImageMgr> lm(TmpResRef);
 	if (!lm) {
-		print("[AREImporter]: No lightmap available.");
+		Log(ERROR, "AREImporter", "No lightmap available.");
 		return NULL;
 	}
 
-	snprintf( TmpResRef, 9, "%sSR", WEDResRef);
+	snprintf( TmpResRef, 9, "%.6sSR", WEDResRef);
 
 	ResourceHolder<ImageMgr> sr(TmpResRef);
 	if (!sr) {
-		print("[AREImporter]: No searchmap available.");
+		Log(ERROR, "AREImporter", "No searchmap available.");
 		return NULL;
 	}
 
-	snprintf( TmpResRef, 9, "%sHT", WEDResRef);
+	snprintf( TmpResRef, 9, "%.6sHT", WEDResRef);
 
 	ResourceHolder<ImageMgr> hm(TmpResRef);
 	if (!hm) {
-		print("[AREImporter]: No heightmap available.");
+		Log(ERROR, "AREImporter", "No heightmap available.");
 		return NULL;
 	}
 
@@ -452,6 +478,15 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	for (i = 0; i < MAX_RESCOUNT; i++) {
 		str->ReadDword( map->SongHeader.SongList + i );
 	}
+
+	if (core->HasFeature(GF_PST_STATE_FLAGS)) {
+		str->Seek(SongHeader + 80, GEM_STREAM_START);
+		str->ReadDword(&map->SongHeader.reverbID);
+	} else {
+		map->SongHeader.reverbID = EFX_PROFILE_REVERB_INVALID;
+	}
+	map->SetupReverbInfo();
+
 	str->Seek( RestHeader + 32, GEM_STREAM_START );
 	for (i = 0; i < MAX_RESCOUNT; i++) {
 		str->ReadDword( map->RestHeader.Strref + i );
@@ -472,7 +507,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	str->ReadWord( &map->RestHeader.DayChance );
 	str->ReadWord( &map->RestHeader.NightChance );
 
-	print("Loading regions");
+	Log(DEBUG, "AREImporter", "Loading regions");
 	core->LoadProgress(70);
 	//Loading InfoPoints
 	for (i = 0; i < InfoPointsCount; i++) {
@@ -563,7 +598,8 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		ip->SetMap(map);
 		ip->Flags = Flags;
 		// ensure repeating traps are armed, fix for bg2 ar1404 mirror trap to fire
-		if (ip->TrapResets()) {
+		// BUT probably not in PST, since that breaks the mausoleum portal in ar0200
+		if (ip->TrapResets() && !core->HasFeature(GF_PST_STATE_FLAGS)) {
 			ip->Trapped = true;
 		}
 		ip->UsePoint.x = PosX;
@@ -598,8 +634,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		}
 	}
 
-	print("Loading containers");
-	//Loading Containers
+	Log(DEBUG, "AREImporter", "Loading containers");
 	for (i = 0; i < ContainersCount; i++) {
 		str->Seek( ContainersOffset + ( i * 0xC0 ), GEM_STREAM_START );
 		ieVariable Name;
@@ -705,8 +740,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		c->OpenFail = OpenFail;
 	}
 
-	print("Loading doors");
-	//Loading Doors
+	Log(DEBUG, "AREImporter", "Loading doors");
 	for (i = 0; i < DoorsCount; i++) {
 		str->Seek( DoorsOffset + ( i * 0xc8 ), GEM_STREAM_START );
 		int count;
@@ -912,8 +946,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		door->SetDialog(Dialog);
 	}
 
-	print("Loading spawnpoints");
-	//Loading SpawnPoints
+	Log(DEBUG, "AREImporter", "Loading spawnpoints");
 	for (i = 0; i < SpawnCount; i++) {
 		str->Seek( SpawnOffset + (i*0xc8), GEM_STREAM_START );
 		ieVariable Name;
@@ -967,11 +1000,10 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	core->LoadProgress(75);
-	print("Loading actors");
-	//Loading Actors
+	Log(DEBUG, "AREImporter", "Loading actors");
 	str->Seek( ActorOffset, GEM_STREAM_START );
 	if (!core->IsAvailable( IE_CRE_CLASS_ID )) {
-		print("[AREImporter]: No Actor Manager Available, skipping actors");
+		Log(WARNING, "AREImporter", "No Actor Manager Available, skipping actors");
 	} else {
 		PluginHolder<ActorMgr> actmgr(IE_CRE_CLASS_ID);
 		for (i = 0; i < ActorCount; i++) {
@@ -979,7 +1011,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			ieResRef CreResRef;
 			ieDword TalkCount;
 			ieDword Orientation, Schedule, RemovalTime;
-			ieWord XPos, YPos, XDes, YDes, Spawned;
+			ieWord XPos, YPos, XDes, YDes, MaxDistance, Spawned;
 			ieResRef Dialog;
 			ieResRef Scripts[8]; //the original order
 			ieDword Flags;
@@ -998,13 +1030,13 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			str->Seek( 4, GEM_CURRENT_POS ); //actor animation, unused
 			str->ReadDword( &Orientation );
 			str->ReadDword( &RemovalTime );
-			str->Seek( 4, GEM_CURRENT_POS ); // TODO: movement restriction distance for spawns, random walk http://gibberlings3.net/forums/index.php?showtopic=21724
+			str->ReadWord( &MaxDistance );
+			str->Seek( 2, GEM_CURRENT_POS ); // apparently unused http://gibberlings3.net/forums/index.php?showtopic=21724
 			str->ReadDword( &Schedule );
 			str->ReadDword( &TalkCount );
 			str->ReadResRef( Dialog );
-			//TODO: script order
-			memset(Scripts,0,sizeof(Scripts));
 
+			memset(Scripts, 0, sizeof(Scripts));
 			str->ReadResRef( Scripts[SCR_OVERRIDE] );
 			str->ReadResRef( Scripts[SCR_GENERAL] );
 			str->ReadResRef( Scripts[SCR_CLASS] );
@@ -1032,7 +1064,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 				crefile = gamedata->GetResource( CreResRef, IE_CRE_CLASS_ID );
 			}
 			if(!actmgr->Open(crefile)) {
-				print("Couldn't read actor: %s!", CreResRef);
+				Log(ERROR, "AREImporter", "Couldn't read actor: %s!", CreResRef);
 				continue;
 			}
 			ab = actmgr->GetActor(0);
@@ -1045,6 +1077,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			ab->Destination.y = YPos;
 			ab->HomeLocation.x = XDes;
 			ab->HomeLocation.y = YDes;
+			ab->maxWalkDistance = MaxDistance;
 			ab->Spawned = Spawned;
 			ab->appearance = Schedule;
 			//copying the scripting name into the actor
@@ -1094,11 +1127,10 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	core->LoadProgress(90);
-	print("Loading animations");
-	//Loading Animations
+	Log(DEBUG, "AREImporter", "Loading animations");
 	str->Seek( AnimOffset, GEM_STREAM_START );
 	if (!core->IsAvailable( IE_BAM_CLASS_ID )) {
-		print("[AREImporter]: No Animation Manager Available, skipping animations");
+		Log(WARNING, "AREImporter", "No Animation Manager Available, skipping animations");
 	} else {
 		for (i = 0; i < AnimCount; i++) {
 			AreaAnimation* anim = new AreaAnimation();
@@ -1137,8 +1169,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		}
 	}
 
-	print("Loading entrances");
-	//Loading Entrances
+	Log(DEBUG, "AREImporter", "Loading entrances");
 	str->Seek( EntrancesOffset, GEM_STREAM_START );
 	for (i = 0; i < EntrancesCount; i++) {
 		ieVariable Name;
@@ -1152,9 +1183,8 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddEntrance( Name, XPos, YPos, Face );
 	}
 
-	print("Loading variables");
+	Log(DEBUG, "AREImporter", "Loading variables");
 	map->locals->LoadInitialValues(ResRef);
-	//Loading Variables
 	str->Seek( VariablesOffset, GEM_STREAM_START );
 	for (i = 0; i < VariablesCount; i++) {
 		ieVariable Name;
@@ -1167,7 +1197,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->locals->SetAt( Name, Value );
 	}
 
-	print("Loading ambients");
+	Log(DEBUG, "AREImporter", "Loading ambients");
 	str->Seek( AmbiOffset, GEM_STREAM_START );
 	for (i = 0; i < AmbiCount; i++) {
 		int j;
@@ -1181,8 +1211,9 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		str->ReadWord( &tmpWord );
 		ambi->origin.y = tmpWord;
 		str->ReadWord( &ambi->radius );
-		str->ReadWord( &ambi->height );
-		str->Seek( 6, GEM_CURRENT_POS );
+		str->Seek( 2, GEM_CURRENT_POS );
+		str->ReadDword( &ambi->pitchVariance );
+		str->ReadWord( &ambi->gainVariance );
 		str->ReadWord( &ambi->gain );
 		for (j = 0;j < MAX_RESCOUNT; j++) {
 			str->ReadResRef( sounds[j] );
@@ -1190,7 +1221,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		str->ReadWord( &tmpWord );
 		str->Seek( 2, GEM_CURRENT_POS );
 		str->ReadDword( &ambi->interval );
-		str->ReadDword( &ambi->perset );
+		str->ReadDword( &ambi->intervalVariance );
 		// schedule bits
 		str->ReadDword( &ambi->appearance );
 		str->ReadDword( &ambi->flags );
@@ -1207,7 +1238,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddAmbient(ambi);
 	}
 
-	print("Loading automap notes");
+	Log(DEBUG, "AREImporter", "Loading automap notes");
 	str->Seek( NoteOffset, GEM_STREAM_START );
 
 	Point point;
@@ -1222,18 +1253,19 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		//add autonote.ini entries
 		if( INInote ) {
 			color = 1; //read only note
-			int count = INInote->GetKeyAsInt( map->GetScriptName(), "count", 0);
+			const char *scriptName = map->GetScriptName();
+			int count = INInote->GetKeyAsInt(scriptName, "count", 0);
 			while (count) {
 				char key[32];
 				int value;
 				sprintf(key, "xPos%d",count);
-				value = INInote->GetKeyAsInt( map->GetScriptName(), key, 0);
+				value = INInote->GetKeyAsInt(scriptName, key, 0);
 				point.x = value;
 				sprintf(key, "yPos%d",count);
-				value = INInote->GetKeyAsInt( map->GetScriptName(), key, 0);
+				value = INInote->GetKeyAsInt(scriptName, key, 0);
 				point.y = value;
 				sprintf(key, "text%d",count);
-				value = INInote->GetKeyAsInt( map->GetScriptName(), key, 0);
+				value = INInote->GetKeyAsInt(scriptName, key, 0);
 				map->AddMapNote( point, color, value);
 				count--;
 			}
@@ -1272,7 +1304,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	//this is a ToB feature (saves the unexploded projectiles)
-	print("Loading traps");
+	Log(DEBUG, "AREImporter", "Loading traps");
 	for (i = 0; i < TrapCount; i++) {
 		ieResRef TrapResRef;
 		ieDword TrapEffOffset;
@@ -1321,7 +1353,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddProjectile( pro, pos, pos);
 	}
 
-	print("Loading tiles");
+	Log(DEBUG, "AREImporter", "Loading tiles");
 	//Loading Tiled objects (if any)
 	str->Seek( TileOffset, GEM_STREAM_START );
 	for (i = 0; i < TileCount; i++) {
@@ -1357,7 +1389,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->TMap->AddTile( ID, Name, Flags, NULL,0, NULL, 0 );
 	}
 
-	print("Loading explored bitmap");
+	Log(DEBUG, "AREImporter", "Loading explored bitmap");
 	i = map->GetExploredMapSize();
 	if (ExploredBitmapSize==i) {
 		map->ExploredBitmap = (ieByte *) malloc(i);
@@ -1374,7 +1406,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 	map->VisibleBitmap = (ieByte *) calloc(i, 1);
 
-	print("Loading wallgroups");
+	Log(DEBUG, "AREImporter", "Loading wallgroups");
 	map->SetWallGroups( tmm->GetPolygonsCount(),tmm->GetWallGroups() );
 	//setting up doors
 	for (i=0;i<DoorsCount;i++) {
@@ -1988,7 +2020,8 @@ int AREImporter::PutActors( DataStream *stream, Map *map)
 		tmpWord = 0;
 		stream->WriteWord( &tmpWord); //unknown
 		stream->WriteDword( &ac->RemovalTime);
-		stream->WriteDword( &tmpDword); //more unknowns
+		stream->WriteWord( &ac->maxWalkDistance);
+		stream->WriteWord( &tmpWord); //more unknowns
 		stream->WriteDword( &ac->appearance);
 		stream->WriteDword( &ac->TalkCount);
 		stream->WriteResRef( ac->GetDialog());
@@ -2107,8 +2140,9 @@ int AREImporter::PutAmbients( DataStream *stream, Map *map)
 		tmpWord = (ieWord) am->origin.y;
 		stream->WriteWord( &tmpWord );
 		stream->WriteWord( &am->radius );
-		stream->WriteWord( &am->height );
-		stream->Write( filling, 6 );
+		stream->Write( filling, 2 );
+		stream->WriteDword( &am->pitchVariance );
+		stream->WriteWord( &am->gainVariance );
 		stream->WriteWord( &am->gain );
 		tmpWord = (ieWord) am->sounds.size();
 		int j;
@@ -2121,7 +2155,7 @@ int AREImporter::PutAmbients( DataStream *stream, Map *map)
 		stream->WriteWord( &tmpWord );
 		stream->Write( filling, 2 );
 		stream->WriteDword( &am->interval );
-		stream->WriteDword( &am->perset );
+		stream->WriteDword( &am->intervalVariance );
 		stream->WriteDword( &am->appearance );
 		stream->WriteDword( &am->flags );
 		stream->Write( filling, 64);
