@@ -25,6 +25,8 @@
 
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 /**CHU File Importer Class
   *@author GemRB Developement Team
   */
@@ -32,7 +34,7 @@
 class CHUImporter : public WindowMgr {
 private:
 	DataStream* str;
-	bool autoFree;
+//	bool autoFree;
 	ieDword WindowCount, CTOffset, WEOffset;
 public: 
 	CHUImporter();
@@ -45,4 +47,6 @@ public:
 	bool Open(DataStream* stream);
 };
 
+}
+
 #endif
