@@ -31,7 +31,9 @@ using namespace GemRB;
 DLGImporter::DLGImporter(void)
 {
 	str = NULL;
-	Version = 0;
+	Version = Flags = 0;
+	StatesCount = TransitionsCount = StateTriggersCount = TransitionTriggersCount = ActionsCount = 0;
+	StatesOffset = TransitionsOffset = StateTriggersOffset = TransitionTriggersOffset = ActionsOffset = 0;
 }
 
 DLGImporter::~DLGImporter(void)
@@ -165,7 +167,7 @@ DialogTransition* DLGImporter::GetTransition(unsigned int index) const
 
 static char** GetStrings(char* string, unsigned int& count);
 
-static Condition* GetCondition(char* string)
+Condition* DLGImporter::GetCondition(char* string) const
 {
 	unsigned int count;
 	char **lines = GetStrings( string, count );
@@ -185,6 +187,7 @@ static Condition* GetCondition(char* string)
 
 Condition* DLGImporter::GetStateTrigger(unsigned int index) const
 {
+	if ((signed)index == -1) index = 0;
 	if (index >= StateTriggersCount) {
 		return NULL;
 	}
