@@ -28,6 +28,8 @@
 
 #include "Interface.h"
 
+namespace GemRB {
+
 class MVEPlay : public MoviePlayer {
 	friend class MVEPlayer;
 private:
@@ -54,4 +56,6 @@ public:
 	int Play();
 };
 
+}
+
 #endif
