@@ -27,6 +27,28 @@
 
 using namespace GemRB;
 
+template <typename TO, typename FROM>
+TO fnptr_cast(FROM ptr) {
+	union {
+		FROM ptr_from;
+		TO ptr_to;
+	} u;
+	u.ptr_from = ptr;
+
+	return u.ptr_to;
+}
+
+#ifdef HAVE_OPENAL_EFX_H
+static LPALGENEFFECTS alGenEffects = NULL;
+static LPALDELETEEFFECTS alDeleteEffects = NULL;
+static LPALISEFFECT alIsEffect = NULL;
+static LPALGENAUXILIARYEFFECTSLOTS alGenAuxiliaryEffectSlots = NULL;
+static LPALDELETEAUXILIARYEFFECTSLOTS alDeleteAuxiliaryEffectSlots = NULL;
+static LPALEFFECTI alEffecti = NULL;
+static LPALEFFECTF alEffectf = NULL;
+static LPALAUXILIARYEFFECTSLOTI alAuxiliaryEffectSloti = NULL;
+#endif
+
 static bool checkALError(const char* msg, log_level level) {
 	int error = alGetError();
 	if (error != AL_NO_ERROR) {
@@ -156,6 +178,13 @@ OpenALAudioDriver::OpenALAudioDriver(void)
 	ambim = NULL;
 	musicThread = NULL;
 	stayAlive = false;
+	hasReverbProperties = false;
+#ifdef HAVE_OPENAL_EFX_H
+	hasEFX = false;
+	efxEffectSlot = efxEffect = 0;
+	memset(&reverbProperties.reverbData, 0, sizeof(reverbProperties.reverbData));
+	reverbProperties.reverbDisabled = true;
+#endif
 }
 
 void OpenALAudioDriver::PrintDeviceList ()
@@ -220,12 +249,73 @@ bool OpenALAudioDriver::Init(void)
 	musicThread = SDL_CreateThread( MusicManager, this );
 #endif
 
+	if (!InitEFX()) {
+		Log(MESSAGE, "OpenAL", "EFX not available.");
+	}
+
 	ambim = new AmbientMgrAL;
 	speech.free = true;
 	speech.ambient = false;
 	return true;
 }
 
+bool OpenALAudioDriver::InitEFX(void) {
+#ifdef HAVE_OPENAL_EFX_H
+	ALCdevice *device = alcGetContextsDevice (alutContext);
+	ALCint auxSends = 0;
+	hasEFX = false;
+
+	if (AL_FALSE == alcIsExtensionPresent(device, "ALC_EXT_EFX")) {
+		return false;
+	}
+
+	alcGetIntegerv(device, ALC_MAX_AUXILIARY_SENDS, 1, &auxSends);
+
+	if (auxSends < 1) {
+		return false;
+	}
+
+	alGenEffects = fnptr_cast<LPALGENEFFECTS>(alGetProcAddress("alGenEffects"));
+	alDeleteEffects = fnptr_cast<LPALDELETEEFFECTS>(alGetProcAddress("alDeleteEffects"));
+	alIsEffect = fnptr_cast<LPALISEFFECT>(alGetProcAddress("alIsEffect"));
+	alGenAuxiliaryEffectSlots = fnptr_cast<LPALGENAUXILIARYEFFECTSLOTS>(alGetProcAddress("alGenAuxiliaryEffectSlots"));
+	alDeleteAuxiliaryEffectSlots = fnptr_cast<LPALDELETEAUXILIARYEFFECTSLOTS>(alGetProcAddress("alDeleteAuxiliaryEffectSlots"));
+	alEffecti = fnptr_cast<LPALEFFECTI>(alGetProcAddress("alEffecti"));
+	alEffectf = fnptr_cast<LPALEFFECTF>(alGetProcAddress("alEffectf"));
+	alAuxiliaryEffectSloti = fnptr_cast<LPALAUXILIARYEFFECTSLOTI>(alGetProcAddress("alAuxiliaryEffectSloti"));
+
+	if (!alGenEffects || !alDeleteEffects || !alIsEffect) {
+		return false;
+	}
+
+	alGenAuxiliaryEffectSlots(1, &efxEffectSlot);
+
+	if (AL_NO_ERROR != alGetError()) {
+		return false;
+	}
+
+	alGenEffects(1, &efxEffect);
+
+	if (AL_NO_ERROR != alGetError()) {
+		return false;
+	}
+
+	if (alIsEffect(efxEffect)) {
+		alEffecti(efxEffect, AL_EFFECT_TYPE, AL_EFFECT_REVERB);
+
+		if (AL_NO_ERROR == alGetError()) {
+			alAuxiliaryEffectSloti(efxEffectSlot, AL_EFFECTSLOT_EFFECT, efxEffect);
+
+			if (AL_NO_ERROR == alGetError()) {
+				hasEFX = true;
+				return true;
+			}
+		}
+	}
+#endif
+	return false;
+}
+
 int OpenALAudioDriver::CountAvailableSources(int limit)
 {
 	ALuint* src = new ALuint[limit+2];
@@ -269,6 +359,13 @@ OpenALAudioDriver::~OpenALAudioDriver(void)
 	ResetMusics();
 	clearBufferCache(true);
 
+#ifdef HAVE_OPENAL_EFX_H
+	if (hasEFX) {
+		alDeleteAuxiliaryEffectSlots(1, &efxEffectSlot);
+		alDeleteEffects(1, &efxEffect);
+	}
+#endif
+
 	ALCdevice *device;
 
 	alcMakeContextCurrent (NULL);
@@ -441,6 +538,17 @@ Holder<SoundHandle> OpenALAudioDriver::Play(const char* ResRef, int XPos, int YP
 	alSourcefv( Source, AL_POSITION, SourcePos );
 	checkALError("Unable to set audio parameters", WARNING);
 
+#ifdef HAVE_OPENAL_EFX_H
+	ieDword efxSetting;
+	core->GetDictionary()->Lookup("Environmental Audio", efxSetting);
+
+	if (efxSetting && hasReverbProperties && ((0 != XPos && 0 != YPos) || (flags & GEM_SND_RELATIVE))) {
+		alSource3i(Source, AL_AUXILIARY_SEND_FILTER, efxEffectSlot, 0, 0);
+	} else {
+		alSource3i(Source, AL_AUXILIARY_SEND_FILTER, 0, 0, 0);
+	}
+#endif
+
 	assert(!stream->delete_buffers);
 
 	stream->Source = Source;
@@ -586,6 +694,7 @@ int OpenALAudioDriver::CreateStream(Holder<SoundMgr> newMusic)
 	if (MusicSource == 0) {
 		alGenSources( 1, &MusicSource );
 		if (checkALError("Unable to create music source", ERROR)) {
+			alDeleteBuffers(MUSICBUFFERS, MusicBuffer);
 			return -1;
 		}
 
@@ -612,7 +721,7 @@ int OpenALAudioDriver::CreateStream(Holder<SoundMgr> newMusic)
 
 void OpenALAudioDriver::UpdateListenerPos(int XPos, int YPos )
 {
-	alListener3f( AL_POSITION, (float) XPos, (float) YPos, 0.0f );
+	alListener3f( AL_POSITION, (float) XPos, (float) YPos, LISTENER_HEIGHT );
 	checkALError("Unable to update listener position.", WARNING);
 }
 
@@ -722,6 +831,16 @@ void OpenALAudioDriver::SetAmbientStreamVolume(int stream, int volume)
 	checkALError("Unable to set ambient volume", WARNING);
 }
 
+void OpenALAudioDriver::SetAmbientStreamPitch(int stream, int pitch)
+{
+	if (streams[stream].free || !streams[stream].ambient)
+		return;
+
+	ALuint source = streams[stream].Source;
+	alSourcef( source, AL_PITCH, 0.01f * pitch );
+	checkALError("Unable to set ambient pitch", WARNING);
+}
+
 bool OpenALAudioDriver::evictBuffer()
 {
 	// Note: this function assumes the caller holds bufferMutex
@@ -809,7 +928,7 @@ int OpenALAudioDriver::MusicManager(void* arg)
 			switch (state) {
 				default:
 					Log(ERROR, "OpenAL", "Unhandled Music state '%d'.", state);
-				//no break
+				//no break, fall through intentionally
 				case AL_PAUSED:
 					driver->MusicPlaying = false;
 					return -1;
@@ -912,8 +1031,10 @@ void OpenALAudioDriver::QueueBuffer(int stream, unsigned short bits,
 		        int channels, short* memory,
 		        int size, int samplerate)
 {
-	ALuint Buffer;
+	streams[stream].delete_buffers = true;
+	streams[stream].ClearProcessedBuffers();
 
+	ALuint Buffer;
 	alGenBuffers(1, &Buffer);
 	if (checkALError("Unable to create buffer", ERROR)) {
 		return;
@@ -921,12 +1042,10 @@ void OpenALAudioDriver::QueueBuffer(int stream, unsigned short bits,
 
 	alBufferData(Buffer, GetFormatEnum(channels, bits), memory, size, samplerate);
 	if (checkALError("Unable to buffer data", ERROR)) {
+		alDeleteBuffers(1, &Buffer);
 		return;
 	}
 
-	streams[stream].delete_buffers = true;
-	streams[stream].ClearProcessedBuffers();
-
 	QueueALBuffer(streams[stream].Source, Buffer);
 }
 
@@ -972,6 +1091,43 @@ int OpenALAudioDriver::QueueALBuffer(ALuint source, ALuint buffer)
 	return GEM_OK;
 }
 
+#ifdef HAVE_OPENAL_EFX_H
+void OpenALAudioDriver::UpdateMapAmbient(MapReverb& mapReverb) {
+	if (hasEFX) {
+		mapReverb.getReverbProperties(reverbProperties);
+		hasReverbProperties = true;
+
+		alDeleteEffects(1, &efxEffect);
+		alGenEffects(1, &efxEffect);
+
+		if (!reverbProperties.reverbDisabled) {
+			alEffecti(efxEffect, AL_EFFECT_TYPE, AL_EFFECT_REVERB);
+
+			alEffectf(efxEffect, AL_REVERB_DENSITY, reverbProperties.reverbData.flDensity);
+			alEffectf(efxEffect, AL_REVERB_DIFFUSION, reverbProperties.reverbData.flDiffusion);
+			alEffectf(efxEffect, AL_REVERB_GAIN, reverbProperties.reverbData.flGain);
+			alEffectf(efxEffect, AL_REVERB_GAINHF, reverbProperties.reverbData.flGainHF);
+			alEffectf(efxEffect, AL_REVERB_DECAY_TIME, reverbProperties.reverbData.flDecayTime);
+			alEffectf(efxEffect, AL_REVERB_DECAY_HFRATIO, reverbProperties.reverbData.flDecayHFRatio);
+			alEffectf(efxEffect, AL_REVERB_REFLECTIONS_GAIN, reverbProperties.reverbData.flReflectionsGain);
+			alEffectf(efxEffect, AL_REVERB_REFLECTIONS_DELAY, reverbProperties.reverbData.flReflectionsDelay);
+			alEffectf(efxEffect, AL_REVERB_LATE_REVERB_GAIN, reverbProperties.reverbData.flLateReverbGain);
+			alEffectf(efxEffect, AL_REVERB_LATE_REVERB_DELAY, reverbProperties.reverbData.flLateReverbDelay);
+			alEffectf(efxEffect, AL_REVERB_AIR_ABSORPTION_GAINHF, reverbProperties.reverbData.flAirAbsorptionGainHF);
+			alEffectf(efxEffect, AL_REVERB_ROOM_ROLLOFF_FACTOR, reverbProperties.reverbData.flRoomRolloffFactor);
+			alEffecti(efxEffect, AL_REVERB_DECAY_HFLIMIT, reverbProperties.reverbData.iDecayHFLimit);
+		} else {
+			alEffecti(efxEffect, AL_EFFECT_TYPE, 0);
+		}
+
+		alAuxiliaryEffectSloti(efxEffectSlot, AL_EFFECTSLOT_EFFECT, efxEffect);
+	}
+}
+#else
+void OpenALAudioDriver::UpdateMapAmbient(MapReverb&) {
+}
+#endif
+
 #include "plugindef.h"
 
 GEMRB_PLUGIN(0x27DD67E0, "OpenAL Audio Driver")
