@@ -22,34 +22,37 @@
 
 #include <cstdio>
 
+using namespace GemRB;
+
 // adapted from ScummVM's mutex.cpp
 
 StackLock::StackLock(SDL_mutex* mutex, const char *mutexName)
-        : _mutex(mutex), _mutexName(mutexName) {
-        lock();
+	: _mutex(mutex), _mutexName(mutexName) {
+	lock();
+	(void)_mutexName; // NOOP to silence clang
 }
 
 StackLock::~StackLock() {
-        unlock();
+	unlock();
 }
 
 void StackLock::lock() {
 #if 0
-        if (_mutexName != NULL) {
-                fprintf(stderr, "Locking mutex %s\n", _mutexName);
+	if (_mutexName != NULL) {
+		fprintf(stderr, "Locking mutex %s\n", _mutexName);
 	}
 #endif
 
-        SDL_mutexP(_mutex);
+	SDL_mutexP(_mutex);
 }
 
 void StackLock::unlock() {
 #if 0
-        if (_mutexName != NULL) {
-                fprintf(stderr, "Unlocking mutex %s\n", _mutexName);
+	if (_mutexName != NULL) {
+		fprintf(stderr, "Unlocking mutex %s\n", _mutexName);
 	}
 #endif
 
-        SDL_mutexV(_mutex);
+	SDL_mutexV(_mutex);
 }
 
