@@ -36,6 +36,7 @@ static ieDword blue_mask = 0x000000ff;
 
 PLTImporter::PLTImporter(void)
 {
+	Width = Height = 0;
 	pixels = NULL;
 	if (DataStream::IsEndianSwitch()) {
 		red_mask = 0x0000ff00;
@@ -62,7 +63,8 @@ bool PLTImporter::Open(DataStream* str)
 
 	str->Read( Signature, 8 );
 	if (strncmp( Signature, "PLT V1  ", 8 ) != 0) {
-		print("[PLTImporter]: Not a valid PLT File.");
+		Log(WARNING, "PLTImporter", "Not a valid PLT File.");
+		core->UseCorruptedHack = true;
 		return false;
 	}
 
