@@ -28,8 +28,8 @@
 		#include <OpenGLES/ES2/gl.h>
 		#include <OpenGLES/ES2/glext.h>
 	#else
-		#include <GLES2/GL2.h>
-		#include <GLES2/GL2ext.h>
+		#include <GLES2/gl2.h>
+		#include <GLES2/gl2ext.h>
 	#endif
 #endif
 
