@@ -36,12 +36,15 @@ namespace GemRB
 		GLSLProgram* programPalSepia; // shader program for paletted sprites  with sepia effect
 		GLSLProgram* programRect; // shader program for drawing rects and lines
 		GLSLProgram* programEllipse; // shader program for drawing ellipses and circles
-		
+
 		Uint32 spritesPerFrame; // sprites counter
 		GLSLProgram* lastUsedProgram; // stores last used program to prevent switching if possible (switching may cause performance lack)
 
 		GLPaletteManager* paletteManager; // palette manager instance
 
+		GLTextureSprite2D *backgroundBuffer;
+		Region GLViewport;
+
 		void useProgram(GLSLProgram* program); // use this instead program->Use()
 		bool createPrograms();
 		void GLBlitSprite(GLTextureSprite2D* spr, const Region& src, const Region& dst, Palette* attachedPal = NULL, unsigned int flags = 0, const Color* tint = NULL, GLTextureSprite2D* mask = NULL);
@@ -67,9 +70,14 @@ namespace GemRB
 		void DrawPolyline(Gem_Polygon* poly, const Color& color, bool fill = false);
 		void DrawEllipse(short cx, short cy, unsigned short xr, unsigned short yr, const Color& color, bool clipped = true);
 		void DrawCircle(short cx, short cy, unsigned short r, const Color& color, bool clipped = true);
+		void SetPixel(short x, short y, const Color& color, bool clipped = true);
 		/*void DrawEllipseSegment(short cx, short cy, unsigned short xr, unsigned short yr, const Color& color, double anglefrom, double angleto, bool drawlines = true, bool clipped = true);*/
 		void DestroyMovieScreen();
 		Sprite2D* GetScreenshot(Region r);
+
+		void DrawBackgroundBuffer();
+		void FreeBackgroundBuffer();
+		void TakeBackgroundBuffer();
 	};
 }
 
