@@ -62,7 +62,9 @@ int SDL20VideoDriver::CreateDisplay(int w, int h, int bpp, bool fs, const char*
 	width = w, height = h;
 
 	Log(MESSAGE, "SDL 2 Driver", "Creating display");
-	Uint32 winFlags = SDL_WINDOW_SHOWN | SDL_WINDOW_OPENGL;
+	// TODO: scale methods can be nearest or linear, and should be settable in config
+	SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "nearest");
+	Uint32 winFlags = SDL_WINDOW_SHOWN | SDL_WINDOW_OPENGL | SDL_WINDOW_RESIZABLE;
 #if TARGET_OS_IPHONE || ANDROID
 	// this allows the user to flip the device upsidedown if they wish and have the game rotate.
 	// it also for some unknown reason is required for retina displays
@@ -72,7 +74,7 @@ int SDL20VideoDriver::CreateDisplay(int w, int h, int bpp, bool fs, const char*
 	SDL_SetHintWithPriority(SDL_HINT_ORIENTATIONS, "LandscapeRight LandscapeLeft", SDL_HINT_DEFAULT);
 #endif
 	if (fullscreen) {
-		winFlags |= SDL_WINDOW_FULLSCREEN;
+		winFlags |= SDL_WINDOW_FULLSCREEN_DESKTOP;
 		//This is needed to remove the status bar on Android/iOS.
 		//since we are in fullscreen this has no effect outside Android/iOS
 		winFlags |= SDL_WINDOW_BORDERLESS;
@@ -148,6 +150,8 @@ doneFormat:
 		width, height, SDL_GetPixelFormatName(format));
 	backBuf = SDL_CreateRGBSurface( 0, width, height,
 									bpp, r, g, b, a );
+	// tmpBuf is here as a truly ugly hack, so we can copy backBuf to tmpBuf before blitting cursors, and then back again after the screen is presented.
+	tmpBuf = SDL_CreateRGBSurface( 0, width, height, bpp, r, g, b, a );
 	this->bpp = bpp;
 
 	if (!backBuf) {
@@ -327,9 +331,16 @@ void SDL20VideoDriver::showYUVFrame(unsigned char** buf, unsigned int *strides,
 
 int SDL20VideoDriver::SwapBuffers(void)
 {
+	//this is not pretty. We make a complete copy of the backBuf into tmpBuf, then copy it back after SDLVideoDriver::SwapBuffers has blitted cursors and tooltips, and SDL_UpdateTexture has copied it to the screentexture.
+	if (Cursor[CursorIndex] && !(MouseFlags & (MOUSE_DISABLED | MOUSE_HIDDEN))) {
+		SDL_BlitSurface(backBuf, NULL, tmpBuf, NULL);
+	}
 	int ret = SDLVideoDriver::SwapBuffers();
 
 	SDL_UpdateTexture(screenTexture, NULL, backBuf->pixels, backBuf->pitch);
+	if (Cursor[CursorIndex] && !(MouseFlags & (MOUSE_DISABLED | MOUSE_HIDDEN))) {
+		SDL_BlitSurface(tmpBuf, NULL, backBuf, NULL);
+	}
 	/*
 	 Commenting this out because I get better performance (on iOS) with SDL_UpdateTexture
 	 Don't know how universal it is yet so leaving this in commented out just in case
@@ -360,6 +371,7 @@ int SDL20VideoDriver::SwapBuffers(void)
 	 SDL_RenderFillRect(renderer, &dst);
 	 }
 	 */
+	SDL_RenderClear(renderer);
 	SDL_RenderCopy(renderer, screenTexture, NULL, NULL);
 	SDL_RenderPresent( renderer );
 	return ret;
@@ -384,7 +396,7 @@ int SDL20VideoDriver::PollEvents()
 
 				BeginMultiGesture(GESTURE_FORMATION_ROTATION);
 			} else {
-				EvntManager->MouseUp( x, y, GEM_MB_MENU, GetModState(SDL_GetModState()));
+				EvntManager->MouseUp(x, y, GEM_MB_MENU, GetModState());
 				ignoreNextFingerUp = 1;
 			}
 		}
@@ -424,7 +436,7 @@ void SDL20VideoDriver::EndMultiGesture(bool success)
 			// we assume this means the gesture doesnt want an up event
 			EvntManager->MouseUp(currentGesture.endPoint.x,
 								 currentGesture.endPoint.y,
-								 currentGesture.endButton, GetModState(SDL_GetModState()) );
+								 currentGesture.endButton, GetModState());
 		}
 	}
 	if (currentGesture.type) {
@@ -451,7 +463,7 @@ bool SDL20VideoDriver::ProcessFirstTouch( int mouseButton )
 
 		// no need to scale these coordinates. they were scaled previously for us.
 		EvntManager->MouseDown( firstFingerDown.x, firstFingerDown.y,
-								mouseButton, GetModState(SDL_GetModState()) );
+								mouseButton, GetModState() );
 
 		ClearFirstTouch();
 		ignoreNextFingerUp--;
@@ -611,7 +623,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 
 						EvntManager->MouseUp(ScaleCoordinateHorizontal(event.tfinger.x),
 											 ScaleCoordinateVertical(event.tfinger.y),
-											 mouseButton, GetModState(SDL_GetModState()) );
+											 mouseButton, GetModState());
 					} else {
 						focusCtrl = EvntManager->GetMouseFocusedControl();
 						if (focusCtrl && focusCtrl->ControlType == IE_GUI_BUTTON)
@@ -639,7 +651,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 					case GESTURE_FORMATION_ROTATION:
 					{
 						SDL_Finger* secondFinger = SDL_GetTouchFinger(event.mgesture.touchId, 1);
-						if (secondFinger && gc->GetTargetMode() == TARGET_MODE_NONE) {
+						if (secondFinger && gc && gc->GetTargetMode() == TARGET_MODE_NONE) {
 							int x = ScaleCoordinateHorizontal(secondFinger->x);// + Viewport.x;
 							int y = ScaleCoordinateVertical(secondFinger->y);// + Viewport.y;
 							gc->OnMouseOver(x, y);
@@ -713,23 +725,38 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 		// discard them if they are produced by touch events
 		// do NOT discard mouse wheel events
 		case SDL_MOUSEMOTION:
-			if (event.motion.which == SDL_TOUCH_MOUSEID) {
-				break;
-			}
 		case SDL_MOUSEBUTTONDOWN:
 		case SDL_MOUSEBUTTONUP:
 			if (event.button.which == SDL_TOUCH_MOUSEID) {
 				break;
 			}
+			else {
+				// we do not want these events to cascade down to SDL_KEYDOWN, so we return here instead of at default .
+				return SDLVideoDriver::ProcessEvent(event);
+			}
 		case SDL_KEYDOWN:
-		case SDL_KEYUP:
 			{
 				SDL_Keycode key = SDL_GetKeyFromScancode(event.key.keysym.scancode);
-				if (key > 32 && key < 127) {
-					// ignore keys that generate text. handeled by SDL_TEXTINPUT
+				if (key == SDLK_SPACE && SDL_GetModState() & KMOD_CTRL) {
+					// special treatment: console popping is the only KEYDOWN event in SDLVideoDriver::ProcessEvent that uses a standard key (and therefore will never be hit). Therefore, implement this here also.
+					core->PopupConsole();
+					break;
+				}
+				if (key == SDLK_LSHIFT || key == SDLK_RSHIFT || key == SDLK_LCTRL || key == SDLK_RCTRL) {
+					// if key is literally just ctrl or shift -- skip it.
+					break;
+				}
+				if (SDL_GetModState() & KMOD_NUM && key >= SDLK_KP_DIVIDE && key <= SDLK_KP_EQUALS && key != SDLK_KP_ENTER) {
+					// ignore numpad keys (handled by SDL_TEXTINPUT) if KMOD_NUM. Never ignore numpad enter.
+					break;
+				}
+				if (key >= 32 && key < 127) {
+					// ignore keys that generate text (these are handeled by SDL_TEXTINPUT).
 					break;
 				}
 			}
+			// fall through
+		case SDL_KEYUP: // we let SDL_KEYUP pass directly to SDLVideo below, since SDL_TEXTINPUT feeds input directly as if it were pressed/keydown.
 		default:
 			return SDLVideoDriver::ProcessEvent(event);
 	}
@@ -772,7 +799,11 @@ void SDL20VideoDriver::SetGamma(int brightness, int /*contrast*/)
 
 bool SDL20VideoDriver::SetFullscreenMode(bool set)
 {
-	if (SDL_SetWindowFullscreen(window, (SDL_bool)set) == GEM_OK) {
+	Uint32 flags = 0;
+	if (set) {
+	flags = SDL_WINDOW_FULLSCREEN_DESKTOP;
+	}
+	if (SDL_SetWindowFullscreen(window, flags) == GEM_OK) {
 		fullscreen = set;
 		return true;
 	}
@@ -790,7 +821,10 @@ bool SDL20VideoDriver::ToggleGrabInput()
 
 bool SDL20VideoDriver::SetSurfaceAlpha(SDL_Surface* surface, unsigned short alpha)
 {
-	bool ret = SDL_SetSurfaceAlphaMod(surface, alpha);
+	bool ret = SDL_SetSurfaceBlendMode(surface, SDL_BLENDMODE_BLEND);
+	if (ret == GEM_OK) {
+		ret = SDL_SetSurfaceAlphaMod(surface, alpha);
+	}
 	if (ret == GEM_OK) {
 		SDL_SetSurfaceRLE(surface, SDL_TRUE);
 	}
@@ -831,6 +865,12 @@ float SDL20VideoDriver::ScaleCoordinateVertical(float y)
 	return y * height;
 }
 
+// note from upstream: on some platforms a device may become seen only after use
+bool SDL20VideoDriver::TouchInputEnabled() const
+{
+	return SDL_GetNumTouchDevices() > 0;
+}
+
 #ifndef USE_OPENGL
 #include "plugindef.h"
 
