@@ -34,7 +34,14 @@
 #include "GUI/Console.h"
 #include "GUI/Window.h"
 
-#include <cmath>
+#if defined(__sgi)
+#  include <math.h>
+#  ifdef __cplusplus
+extern "C" double round(double);
+#  endif
+#else
+#  include <cmath>
+#endif
 
 using namespace GemRB;
 
@@ -65,7 +72,7 @@ SDLVideoDriver::SDLVideoDriver(void)
 	lastMouseDownTime = lastMouseMoveTime = GetTickCount();
 	subtitlestrref = 0;
 	subtitletext = NULL;
-	disp = NULL;
+	disp = tmpBuf =  NULL;
 }
 
 SDLVideoDriver::~SDLVideoDriver(void)
@@ -155,7 +162,7 @@ int SDLVideoDriver::PollEvents()
 		GetMousePos(x, y);
 		lastMouseDownTime=lastTime + EvntManager->GetRKDelay();
 		if (!core->ConsolePopped) {
-			EvntManager->MouseUp( x, y, GEM_MB_ACTION, GetModState(SDL_GetModState()) );
+			EvntManager->MouseUp( x, y, GEM_MB_ONGOING_ACTION, GetModState() );
 			Control* ctl = EvntManager->GetMouseFocusedControl();
 			if (ctl && ctl->ControlType == IE_GUI_BUTTON)
 				// these are repeat events so the control should stay pressed
@@ -339,7 +346,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 			CursorPos.x = event.button.x; // - mouseAdjustX[CursorIndex];
 			CursorPos.y = event.button.y; // - mouseAdjustY[CursorIndex];
 			if (!core->ConsolePopped)
-				EvntManager->MouseDown( event.button.x, event.button.y, 1 << ( event.button.button - 1 ), GetModState(SDL_GetModState()) );
+				EvntManager->MouseDown( event.button.x, event.button.y, 1 << ( event.button.button - 1 ), GetModState() );
 			break;
 		case SDL_MOUSEBUTTONUP:
 			if (CursorIndex != VID_CUR_DRAG)
@@ -347,7 +354,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 			CursorPos.x = event.button.x;
 			CursorPos.y = event.button.y;
 			if (!core->ConsolePopped)
-				EvntManager->MouseUp( event.button.x, event.button.y, 1 << ( event.button.button - 1 ), GetModState(SDL_GetModState()) );
+				EvntManager->MouseUp( event.button.x, event.button.y, 1 << ( event.button.button - 1 ), GetModState() );
 			break;
 	}
 	return GEM_OK;
@@ -599,22 +606,7 @@ void SDLVideoDriver::BlitGameSprite(const Sprite2D* spr, int x, int y,
 		}
 	}
 
-	// global tint
-	if (!anchor && core->GetGame()) {
-		const Color *totint = core->GetGame()->GetGlobalTint();
-		if (totint) {
-			if (flags & BLIT_TINTED) {
-				tint.r = (tint.r * totint->r) >> 8;
-				tint.g = (tint.g * totint->g) >> 8;
-				tint.b = (tint.b * totint->b) >> 8;
-			} else {
-				flags |= BLIT_TINTED;
-				tint = *totint;
-				tint.a = 255;
-			}
-		}
-	}
-
+	// global tint is handled by the callers
 
 	// implicit flags:
 	const unsigned int blit_TINTALPHA =    0x40000000U;
