@@ -27,6 +27,8 @@
 
 #include "Spell.h"
 
+namespace GemRB {
+
 
 class SPLImporter : public SpellMgr {
 private:
@@ -44,4 +46,6 @@ private:
 };
 
 
+}
+
 #endif
